/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64
#define NIM_EmulateOverflowChecks

#include "nimbase.h"
#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyTuple__kN8up2W6YKc5YA9avn5mV5w tyTuple__kN8up2W6YKc5YA9avn5mV5w;
typedef struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA;
typedef struct tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg;
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw tySequence__4eRCaZmrYLLw2k30GPTiMw;
typedef struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content tySequence__4eRCaZmrYLLw2k30GPTiMw_Content;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q tySequence__xOJ2kx2lq9bBfIm3IXnde3Q;
typedef struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content;
typedef struct tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA;
typedef struct tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ;
typedef struct tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA;
typedef struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw tyTuple__QeWl6B6ffS4pU6WWrtcrDw;
typedef struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
typedef NU8 tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w;
typedef NU8 tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg;
typedef NU8 tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA;
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
typedef NU8 tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw;
typedef NU8 tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw;
typedef NU8 tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw;
struct tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA {
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw targetCPU;
	tyEnum_TSystemCPU__3f9cinURS2hpZEHtBX69bm9cw hostCPU;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw targetOS;
	tyEnum_TSystemOS__Ze8KQVBa9adXItTgDtW0Iqw hostOS;
	NI intSize;
	NI floatSize;
	NI ptrSize;
	NimStringV2 tnl;
};
typedef NU32 tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NU64 tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
typedef NU8 tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ;
typedef NU8 tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ;
typedef NU8 tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg;
typedef NU8 tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw;
typedef NU8 tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA;
struct tySequence__4eRCaZmrYLLw2k30GPTiMw {
  NI len; tySequence__4eRCaZmrYLLw2k30GPTiMw_Content* p;
};
struct tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw {
	tySequence__4eRCaZmrYLLw2k30GPTiMw data;
	NI counter;
};
typedef NU32 tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ;
typedef NU8 tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA;
typedef NU8 tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng;
typedef NU8 tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA;
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
typedef NU8 tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q {
  NI len; tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content* p;
};
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_SuggestcolonObjectType___UyASNXAqAMRY5zJmcRD9ccA* result_p0, void* ClE_0);
void* ClE_0;
} tyProc__QQyR5yGA47tr5TwLxcC4Gw;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (NimStringV2 output_p0, void* ClE_0);
void* ClE_0;
} tyProc__k2HFjxisIgDALbEUFojxaQ;
typedef struct {
N_NIMCALL_PTR(void, ClP_0) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3, void* ClE_0);
void* ClE_0;
} tyProc__DA9aR62IikoxFqfC5rIT9cuw;
struct tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg {
	tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw backend;
	tyObject_Target__GzbDkV2u8Pgzlf9azvC43FA target;
	NI linesCompiled;
	tySet_tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ options;
	tySet_tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A globalOptions;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* macrosToExpand;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* arcToExpand;
	tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw m;
	tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ filenameOption;
	NimStringV2 unitSep;
	NI evalTemplateCounter;
	NI evalMacroCounter;
	NI8 exitcode;
	tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ cmd;
	NimStringV2 cmdInput;
	NIM_BOOL projectIsCmd;
	NIM_BOOL implicitCmd;
	tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg selectedGC;
	tyEnum_ExceptionSystem__dJ6sXW7k8NDYNNBUjVZmnw exc;
	NIM_BOOL hintProcessingDots;
	NI verbosity;
	NI numberOfProcessors;
	NF lastCmdTime;
	tyEnum_SymbolFilesOption__2eyIIreuRXhYT9buPPZbBYA symbolFiles;
	NI spellSuggestMax;
	tyObject_HashSet__8IGL0eIK5PYDsNGVA78Wmw cppDefines;
	NimStringV2 headerFile;
	NimStringV2 nimbasePattern;
	tySet_tyEnum_Feature__cS3g03qGjroRW9aHnqpz8MQ features;
	tySet_tyEnum_LegacyFeature__yvNVqOQTgcxHpvo1MvfBfA legacyFeatures;
	NimStringV2 arguments;
	tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng ideCmd;
	tyEnum_TSystemCC__A5wZwpTXF1SiKGvwgH1wrA cCompiler;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw modifiedyNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw cmdlineNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw foreignPackageNotes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw notes;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw warningAsErrors;
	tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw mainPackageNotes;
	NI mainPackageId;
	NI errorCounter;
	NI hintCounter;
	NI warnCounter;
	NI errorMax;
	NI maxLoopIterationsVM;
	NI maxCallDepthVM;
	NIM_BOOL isVmTrace;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* configVars;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* symbols;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* packageCache;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ nimblePaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ searchPaths;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lazyPaths;
	NimStringV2 outFile;
	NimStringV2 outDir;
	NimStringV2 jsonBuildFile;
	NimStringV2 prefixDir;
	NimStringV2 libpath;
	NimStringV2 nimcacheDir;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* dllOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* moduleOverrides;
	tyObject_StringTableObj__eKsdjq89aDBcvVY68b206Qg* cfileSpecificOptions;
	NimStringV2 projectName;
	NimStringV2 projectPath;
	NimStringV2 projectFull;
	NIM_BOOL projectIsStdin;
	NimStringV2 stdinFile;
	tySet_tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw lastMsgWasDot;
	NI32 projectMainIdx;
	NI32 projectMainIdx2;
	NimStringV2 command;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ commandArgs;
	NimStringV2 commandLine;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ extraCmds;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitImports;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ implicitIncludes;
	NimStringV2 docSeeSrcUrl;
	NimStringV2 docRoot;
	NimStringV2 docCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ configFiles;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cIncludes;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ cLinkedLibs;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ externalToLink;
	NimStringV2 linkOptionsCmd;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ compileOptionsCmd;
	NimStringV2 linkOptions;
	NimStringV2 compileOptions;
	NimStringV2 cCompilerPath;
	tySequence__xOJ2kx2lq9bBfIm3IXnde3Q toCompile;
	tyProc__QQyR5yGA47tr5TwLxcC4Gw suggestionResultHook;
	NI suggestVersion;
	NI suggestMaxResults;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastLineInfo;
	tyProc__k2HFjxisIgDALbEUFojxaQ writelnHook;
	tyProc__DA9aR62IikoxFqfC5rIT9cuw structuredErrorHook;
	NimStringV2 cppCustomNamespace;
	NimStringV2 nimMainPrefix;
	tyObject_ProfileDatacolonObjectType___R9cEb9cNTzPRldVmD9bCDO0xQ* vmProfileData;
	NIM_BOOL expandProgress;
	NI expandLevels;
	NimStringV2 expandNodeResult;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA expandPosition;
	NimStringV2 currentConfigDir;
	NI clientProcessId;
};
struct tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg {
	tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA a;
	tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA b;
};
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3);
typedef NimStringV2 tyArray__YgExxhfgKcesA5EOUj1MOA[1];
typedef NimStringV2 tyArray__dyW7vpmfeTYw8kX3EXuaJA[3];
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
typedef NU8 tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A;
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_28) (NimStringV2 output_p0);
typedef NU8 tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
typedef NU8 tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw;
typedef NU16 tySet_tyEnum_Style__eUA1W69bfnUNuraRJtJ0MmA;
typedef NU8 tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw;
typedef NU8 tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ;
typedef NimStringV2 tyArray__pKMShAYxu8WJVt39cC69bQ9aQ[124];
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_49) (tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* config_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 msg_p2, tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA severity_p3);
typedef NimStringV2 tyArray__A2YC0h9cZydgH7zGAndH9bLg[6];
typedef NU8 tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg;
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_60) (NimStringV2 output_p0);
typedef NimStringV2 tyArray__Seu7uK9aaOSN0BK3EAjjSHw[4];
struct tyTuple__kN8up2W6YKc5YA9avn5mV5w {
	NimStringV2 Field0;
	NI Field1;
	NI Field2;
};
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_71) (NimStringV2 output_p0);
typedef NimStringV2 tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ[2];
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_91) (NimStringV2 output_p0);
typedef NU8 tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw;
typedef NU8 tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw;
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_100) (NimStringV2 output_p0);
typedef N_CLOSURE_PTR(void, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_115) (NimStringV2 output_p0);
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
struct tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA {
	tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA Sup;
};
typedef NU8 tyEnum_BinaryPrefixMode__DD8vm6t9bnCX9aiA69bRJXJtQ;
typedef NU8 tyEnum_FloatFormatMode__CTUpdhZ6zDNw9cC9acViKeYg;
typedef NimStringV2 tyArray__ZZ0jy0VwqpvoX7GeaU0HUw[12];
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tyTuple__QeWl6B6ffS4pU6WWrtcrDw {
	NI Field0;
	NimStringV2 Field1;
};
struct tySequence__4eRCaZmrYLLw2k30GPTiMw_Content { NI cap; tyTuple__QeWl6B6ffS4pU6WWrtcrDw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
typedef NU8 tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ;
struct tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg {
	NimStringV2 nimname;
	NimStringV2 cname;
	NimStringV2 obj;
	tySet_tyEnum_CfileFlag__qhMBL5cBz484papsb5WgFQ flags;
	NimStringV2 customArgs;
};
struct tySequence__xOJ2kx2lq9bBfIm3IXnde3Q_Content { NI cap; tyObject_Cfile__DANcxQKXbKf7Ve5cK3l3Wg data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
static N_INLINE(NIM_BOOL, contains__msgs_u1062)(tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg s_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA value_p1);
static N_INLINE(tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg, dotdot___msgs_u994)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA a_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___lineinfos_u134)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA e_p0);
N_LIB_PRIVATE N_NIMCALL(void, writeContext__msgs_u1111)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastinfo_p1);
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lineinfos_u1910)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ* dest_p0, tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ src_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_u1103)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA a_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA b_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatVarargs)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, concat__msgs_u443)(NimStringV2* strings_p0, NI strings_p0Len_0);
N_NIMCALL(NimStringV2, rawNewString)(NI cap_p0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toMsgFilename__msgs_u688)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFilenameOption__msgs_u676)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ opt_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toProjPath__msgs_u616)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalImportAux__options_u4231)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 file_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, noslastPathPart)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NI, nsuCountString)(NimStringV2 s_p0, NimStringV2 sub_p1, NIM_BOOL overlapping_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___system_u2688)(NimStringV2* dest_p0);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1);
N_LIB_PRIVATE N_NIMCALL(void, addInt__stdZprivateZdigitsutils_u187)(NimStringV2* result_p0, NI64 x_p1);
N_LIB_PRIVATE N_NIMCALL(void, flushDot__msgs_u40)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
N_LIB_PRIVATE N_NIMCALL(void, write__stdZsyncio_u254)(FILE* f_p0, NimStringV2 s_p1);
static N_INLINE(void, writeLine__msgs_u470)(FILE* f_p0, NimStringV2* x_p1, NI x_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(void, flushFile__stdZsyncio_u279)(FILE* f_p0);
N_LIB_PRIVATE N_NIMCALL(void, setStyle__pureZterminal_u415)(FILE* f_p0, tySet_tyEnum_Style__eUA1W69bfnUNuraRJtJ0MmA style_p1);
N_LIB_PRIVATE N_NIMCALL(void, resetAttributes__pureZterminal_u376)(FILE* f_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u1907)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ dest_p0);
static N_INLINE(NIM_BOOL, hasWarn__options_u617)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasHint__options_u557)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getMessageStr__msgs_u870)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p0, NimStringV2 arg_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatOpenArray)(NimStringV2 formatstr_p0, NimStringV2* a_p1, NI a_p1Len_0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, msgKindToString__msgs_u867)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA kind_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuFormatSingleElem)(NimStringV2 formatstr_p0, NimStringV2 a_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ignoreMsgBecauseOfIdeTools__msgs_u1175)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p1);
N_LIB_PRIVATE N_NIMCALL(void, msgWrite__msgs_u844)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSurroundingSrc__msgs_u1215)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, sourceLine__msgs_u1210)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1);
N_LIB_PRIVATE N_NIMCALL(NI, numLines__msgs_u1199)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPathConsiderDirty__msgs_u657)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1);
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(FILE*, open__stdZsyncio_u493)(NimStringV2 filename_p0, tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg mode_p1, NI bufSize_p2);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, readLine__stdZsyncio_u292)(FILE* f_p0, NimStringV2* line_p1);
N_LIB_PRIVATE N_NIMCALL(void, addSourceLine__msgs_u1191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, NimStringV2 line_p2);
N_LIB_PRIVATE N_NIMCALL(void, add__stdZenumutils_u71)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* x_p0, NimStringV2 y_p1);
N_LIB_PRIVATE N_NIMCALL(void, close__stdZsyncio_u269)(FILE* f_p0);
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2);
static N_INLINE(Exception*, nimBorrowCurrentException)(void);
static N_INLINE(void, popCurrentException)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u3656)(Exception** dest_p0, Exception* src_p1, NIM_BOOL cyclic_p2);
static N_INLINE(NimStringV2, spaces__pureZstrutils_u1139)(NI n_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuRepeatChar)(NIM_CHAR c_p0, NI count_p1);
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(void, setForegroundColor__pureZterminal_u511)(FILE* f_p0, tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg fg_p1, NIM_BOOL bright_p2);
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* info_p0);
N_LIB_PRIVATE N_NIMCALL(void, handleError__msgs_u964)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p1, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p2, NimStringV2 s_p3, NIM_BOOL ignoreMsg_p4);
N_LIB_PRIVATE N_NIMCALL(void, log__msgs_u881)(NimStringV2 s_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, open__stdZsyncio_u414)(FILE** f_p0, NimStringV2 filename_p1, tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg mode_p2, NI bufSize_p3);
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosjoinPath)(NimStringV2 head_p0, NimStringV2 tail_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosgetHomeDir)(void);
N_LIB_PRIVATE N_NIMCALL(void, quit__msgs_u892)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, isDefined__options_u959)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 symbol_p1);
N_LIB_PRIVATE N_NOINLINE(void, raiseAssert__stdZassertions_u15)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, quit__system_u8018)(NimStringV2 errormsg_p0, NI errorcode_p1);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, stackTraceAvailable__system_u4030)(void);
N_LIB_PRIVATE N_NIMCALL(void, writeStackTrace__system_u2709)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, createDocLink__lineinfos_u6)(NimStringV2 urlSuffix_p0);
static N_INLINE(void, quit__system_u7999)(NI errorcode_p0);
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__lineinfos_u299)(NimStringV2 msg_p0);
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_u737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1, tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw flags_p2);
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u155)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NIM_BOOL* isKnownFile_p2);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, canonicalizePath__options_u3669)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 path_p1);
static N_INLINE(void, canonicalCase__msgs_u99)(NimStringV2* path_p0);
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, hasKey__msgs_u142)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(NI32*, X5BX5D___msgs_u253)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, NimStringV2 key_p1);
N_LIB_PRIVATE N_NIMCALL(void, add__msgs_u342)(tySequence__hTEiKNj3evQAjIXUI21elA* x_p0, tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw* y_p1);
N_LIB_PRIVATE N_NIMCALL(void, newFileInfo__msgs_u91)(NimStringV2 fullPath_p0, NimStringV2 projPath_p1, tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw* Result);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosextractFilename)(NimStringV2 path_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeCString__msgs_u83)(NimStringV2 s_p0);
static N_INLINE(NF, toFloat__system_u1695)(NI i_p0);
static N_INLINE(void, toCChar__msgs_u80)(NIM_CHAR c_p0, NimStringV2* result_p1);
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuToOctal)(NIM_CHAR c_p0);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(void, eqsink___system_u2700)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, relativeTo__pathutils_u196)(NimStringV2 fullPath_p0, NimStringV2 baseFilename_p1, NIM_CHAR sep_p2);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lineinfos_u646)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, NimStringV2 key_p1, NI32 val_p2);
N_LIB_PRIVATE N_NIMCALL(void, setLen__system_u5431)(tySequence__sM4lkSb7zS6F7OVMvW9cffQ* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7);
N_LIB_PRIVATE N_NIMCALL(void, add__msgs_u573)(tySequence__E0kio2ZnplNTuln9bsnljSA* x_p0, tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ y_p1);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0);
N_LIB_PRIVATE N_NIMCALL(void, setLen__lineinfos_u1862)(tySequence__E0kio2ZnplNTuln9bsnljSA* s_p0, NI newlen_p1);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
static N_INLINE(NIM_BOOL, lteqpercent___system_u1072)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nosexpandFilename)(NimStringV2 filename_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quotedFilename__msgs_u1630)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fi_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, formatSize__pureZstrutils_u2341)(NI64 bytes_p0, NIM_CHAR decimalSep_p1, tyEnum_BinaryPrefixMode__DD8vm6t9bnCX9aiA69bRJXJtQ prefix_p2, NIM_BOOL includeSpace_p3);
N_LIB_PRIVATE N_NIMCALL(NI, getMaxMem__system_u7220)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___systemZdollars_u9)(NI xX60gensym0__p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u213)(tyEnum_TGCMode__WW4nMw6ktfZDxJ6q84Mivg e_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, nsuformatFloat)(NF f_p0, tyEnum_FloatFormatMode__CTUpdhZ6zDNw9cC9acViKeYg format_p1, NI precision_p2, NIM_CHAR decimalSep_p3);
N_LIB_PRIVATE N_NIMCALL(NF, epochTime__pureZtimes_u5209)(void);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___options_u3939)(NimStringV2 x_p0);
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, absOutFile__options_u3622)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0);
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_3 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static NIM_CONST tyProc__DA9aR62IikoxFqfC5rIT9cuw TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4 = {NIM_NIL,NIM_NIL};
static const struct {
  NI cap; NIM_CHAR data[40+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_5 = { 40 | NIM_STRLIT_FLAG, "template/generic instantiation from here" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6 = {40, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_5};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_8 = {40, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_5};
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_9 = { 48 | NIM_STRLIT_FLAG, "template/generic instantiation of `$1` from here" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_10 = {48, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_9};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_11 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12 = { 12 | NIM_STRLIT_FLAG, "command line" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_13 = {12, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14 = { 3 | NIM_STRLIT_FLAG, "\?\?\?" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_15 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_16 = {12, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_17 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18 = { 2 | NIM_STRLIT_FLAG, ".." };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_19 = {2, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_18};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_20 = { 1 | NIM_STRLIT_FLAG, "(" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_21 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_20};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_22 = { 2 | NIM_STRLIT_FLAG, ", " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_23 = {2, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_22};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24 = { 1 | NIM_STRLIT_FLAG, ")" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26 = { 1 | NIM_STRLIT_FLAG, " " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29 = { 1 | NIM_STRLIT_FLAG, "\012" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_32 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_33 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_34 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_35 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36 = { 7 | NIM_STRLIT_FLAG, "Error: " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_38 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_39 = { 9 | NIM_STRLIT_FLAG, "Warning: " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_40 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_39};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_41 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_42 = { 6 | NIM_STRLIT_FLAG, "Hint: " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_43 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_42};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_44 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_45 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_46 = { 5 | NIM_STRLIT_FLAG, " [$1]" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_47 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_46};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_48 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_50 = { 1 | NIM_STRLIT_FLAG, "." };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_51 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_50};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_52 = { 3 | NIM_STRLIT_FLAG, "\012  " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_53 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_52};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_54 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_55 = {12, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_12};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_56 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_57 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_58 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_52};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_59 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_61 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_62 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_63 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_20};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_64 = {2, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_22};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_65 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_24};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_66 = { 28 | NIM_STRLIT_FLAG, " compiler msg initiated here" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_67 = {28, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_66};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_68 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_46};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_69 = { 9 | NIM_STRLIT_FLAG, "MsgOrigin" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_70 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_69};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_72 = {28, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_66};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_73 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_46};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_74 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_69};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_75 = {28, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_66};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_76 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_46};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_77 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_69};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_78 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_79 = {28, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_66};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_80 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_46};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_81 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_69};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_82 = { 14 | NIM_STRLIT_FLAG, "nimsuggest.log" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_83 = {14, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_82};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_84 = { 8 | NIM_STRLIT_FLAG, "nimDebug" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_85 = {8, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_84};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_86 = {8, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_84};
static const struct {
  NI cap; NIM_CHAR data[119+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_87 = { 119 | NIM_STRLIT_FLAG, "No stack traceback available\012To create a stacktrace, rerun compilation with \'./koch temp $1 <file>\', see $2 for details" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_88 = {119, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_87};
static const struct {
  NI cap; NIM_CHAR data[34+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_89 = { 34 | NIM_STRLIT_FLAG, "intern.html#debugging-the-compiler" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_90 = {34, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_89};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_92 = {119, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_87};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_93 = {34, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_89};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_94 = {119, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_87};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_95 = {34, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_89};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_96 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_29};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_97 = {119, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_87};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_98 = {34, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_89};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_99 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_101 = { 9 | NIM_STRLIT_FLAG, "Warnings:" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_102 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_101};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_103 = { 9 | NIM_STRLIT_FLAG, "  [$1] $2" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_104 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_103};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_105 = { 1 | NIM_STRLIT_FLAG, "x" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_106 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_105};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_107 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_108 = { 6 | NIM_STRLIT_FLAG, "Hints:" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_109 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_108};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_110 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_103};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_111 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_105};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_112 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_113 = { 1 | NIM_STRLIT_FLAG, "\"" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_114 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_113};
extern TNimTypeV2 NTIv2__CLyaY3uTAyl9bLjvrz9aqX9bA_;
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_116 = { 12 | NIM_STRLIT_FLAG, "suggest done" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_117 = {12, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_116};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_118 = {9, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_39};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_119 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_42};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_120 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_36};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_121 = {1, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_26};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_122 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_14};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_123 = { 8 | NIM_STRLIT_FLAG, " peakmem" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_124 = {8, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_123};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_125 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_126 = {0, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_2};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_127 = { 8 | NIM_STRLIT_FLAG, "mm: $#; " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_128 = {8, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_127};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_129 = { 13 | NIM_STRLIT_FLAG, "threads: on; " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_130 = {13, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_129};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_131 = { 5 | NIM_STRLIT_FLAG, "opt: " };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_132 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_131};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_133 = { 5 | NIM_STRLIT_FLAG, "speed" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_134 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_133};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_135 = { 4 | NIM_STRLIT_FLAG, "size" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_136 = {4, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_135};
static const struct {
  NI cap; NIM_CHAR data[54+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_137 = { 54 | NIM_STRLIT_FLAG, "none (DEBUG BUILD, `-d:release` generates faster code)" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_138 = {54, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_137};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_139 = { 6 | NIM_STRLIT_FLAG, "danger" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_140 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_139};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_141 = { 10 | NIM_STRLIT_FLAG, " -d:danger" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_142 = {10, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_141};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_143 = { 7 | NIM_STRLIT_FLAG, "release" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_144 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_143};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_145 = { 11 | NIM_STRLIT_FLAG, " -d:release" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_146 = {11, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_145};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_147 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_131};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_148 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_139};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_149 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_133};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_150 = {10, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_141};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_151 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_143};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_152 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_133};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_153 = {11, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_145};
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_154 = {54, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_137};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_155 = { 10 | NIM_STRLIT_FLAG, "; options:" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_156 = {10, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_155};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_157 = { 13 | NIM_STRLIT_FLAG, "unknownOutput" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_158 = {13, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_157};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_159 = { 6 | NIM_STRLIT_FLAG, "stdout" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_160 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_159};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_161 = { 5 | NIM_STRLIT_FLAG, "build" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_162 = {5, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_161};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_163 = { 3 | NIM_STRLIT_FLAG, "loc" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_164 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_163};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_165 = { 3 | NIM_STRLIT_FLAG, "sec" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_166 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_165};
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_167 = { 3 | NIM_STRLIT_FLAG, "mem" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_168 = {3, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_167};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_169 = { 7 | NIM_STRLIT_FLAG, "project" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_170 = {7, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_169};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_171 = { 6 | NIM_STRLIT_FLAG, "output" };
static const NimStringV2 TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_172 = {6, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_171};
static const struct {
  NI cap; NIM_CHAR data[59+1];
} TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_174 = { 59 | NIM_STRLIT_FLAG, "/home/runner/work/nightlies/nightlies/nim/compiler/msgs.nim" };
extern NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364;
extern NIM_CONST tyArray__pKMShAYxu8WJVt39cC69bQ9aQ MsgKindToStr__lineinfos_u137;
N_LIB_PRIVATE NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA gCmdLineInfo__msgs_u442 = {((NU16)1), ((NI16)1), ((NI32)-3)}
;
static NIM_CONST tyTuple__kN8up2W6YKc5YA9avn5mV5w TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_173 = {{59, (NimStrPayload*)&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_174},
((NI)718),
((NI)12)}
;
extern NIM_BOOL nimInErrorMode__system_u4138;
extern Exception* currException__system_u3623;
static N_INLINE(NIM_BOOL, contains__msgs_u1062)(tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg s_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA value_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (s_p0.a <= value_p1);
	if (!(T1_)) goto LA2_;
	T1_ = (value_p1 <= s_p0.b);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg, dotdot___msgs_u994)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA a_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA b_p1) {
	tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg result;
	result.a = a_p0;
	result.b = b_p1;
	return result;
}
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, eqeq___msgs_u1103)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA a_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA b_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (a_p0.line == b_p1.line);
	if (!(T1_)) goto LA2_;
	T1_ = (a_p0.fileIndex == b_p1.fileIndex);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, concat__msgs_u443)(NimStringV2* strings_p0, NI strings_p0Len_0) {
	NimStringV2 result;
	NI totalLen_1;
	result.len = 0; result.p = NIM_NIL;
	totalLen_1 = ((NI)0);
	{
		NimStringV2* s_1;
		NI i_1;
		s_1 = (NimStringV2*)0;
		i_1 = ((NI)0);
		{
			while (1) {
				if (!(i_1 < strings_p0Len_0)) goto LA3;
				s_1 = (&strings_p0[i_1]);
				totalLen_1 += (*s_1).len;
				i_1 += ((NI)1);
			} LA3: ;
		}
	}
	result = rawNewString((totalLen_1));
	{
		NimStringV2* s_2;
		NI i_2;
		s_2 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < strings_p0Len_0)) goto LA6;
				s_2 = (&strings_p0[i_2]);
				prepareAdd((&result), (*s_2).len + 0);
appendString((&result), (*s_2));
				i_2 += ((NI)1);
			} LA6: ;
		}
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPath__msgs_u624)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1) {
	NimStringV2 result;
	{
		NIM_BOOL T3_;
		NimStringV2 T7_;
		T3_ = (NIM_BOOL)0;
		T3_ = (fileIdx_p1 < ((NI32)0));
		if (T3_) goto LA4_;
		T3_ = (conf_p0 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL));
LA4_: ;
		if (!T3_) goto LA5_;
		T7_.len = 0; T7_.p = NIM_NIL;
		{
			if (!(fileIdx_p1 == ((NI32)-3))) goto LA10_;
			result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_13;
		}
		goto LA8_;
LA10_: ;
		{
			result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_15;
		}
LA8_: ;
	}
	goto LA1_;
LA5_: ;
	{
		NimStringV2 colontmpD_;
		colontmpD_ = eqdup___system_u2697((*conf_p0).m.fileInfos.p->data[fileIdx_p1].fullPath);
		result = colontmpD_;
	}
LA1_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toProjPath__msgs_u616)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1) {
	NimStringV2 result;
	NimStringV2 T1_;
	T1_.len = 0; T1_.p = NIM_NIL;
	{
		NIM_BOOL T4_;
		NimStringV2 T8_;
		T4_ = (NIM_BOOL)0;
		T4_ = (fileIdx_p1 < ((NI32)0));
		if (T4_) goto LA5_;
		T4_ = (conf_p0 == ((tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg*) NIM_NIL));
LA5_: ;
		if (!T4_) goto LA6_;
		T8_.len = 0; T8_.p = NIM_NIL;
		{
			if (!(fileIdx_p1 == ((NI32)-3))) goto LA11_;
			result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_16;
		}
		goto LA9_;
LA11_: ;
		{
			result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_17;
		}
LA9_: ;
	}
	goto LA2_;
LA6_: ;
	{
		NimStringV2 colontmpD_;
		colontmpD_ = eqdup___system_u2697((*conf_p0).m.fileInfos.p->data[fileIdx_p1].projPath);
		result = colontmpD_;
	}
LA2_: ;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4138);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFilenameOption__msgs_u676)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ opt_p2) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	switch (opt_p2) {
	case ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0):
	{
		result = toFullPath__msgs_u624(conf_p0, fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)1):
	{
		result = toProjPath__msgs_u616(conf_p0, fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)2):
	{
		NimStringV2 absPath_1;
		absPath_1.len = 0; absPath_1.p = NIM_NIL;
		absPath_1 = toFullPath__msgs_u624(conf_p0, fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		result = canonicalImportAux__options_u4231(conf_p0, absPath_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
		{
			LA4_:;
		}
		{
			eqdestroy___system_u2691(absPath_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	break;
	case ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)4):
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD_ = toProjPath__msgs_u616(conf_p0, fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		result = noslastPathPart(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		eqdestroy___system_u2691(colontmpD_);
	}
	break;
	case ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)3):
	{
		NimStringV2 absPath_2;
		NimStringV2 relPath_1;
		NimStringV2 T9_;
		absPath_2.len = 0; absPath_2.p = NIM_NIL;
		relPath_1.len = 0; relPath_1.p = NIM_NIL;
		absPath_2 = toFullPath__msgs_u624(conf_p0, fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		relPath_1 = toProjPath__msgs_u616(conf_p0, fileIdx_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T9_.len = 0; T9_.p = NIM_NIL;
		{
			NIM_BOOL T12_;
			NI T14_;
			T12_ = (NIM_BOOL)0;
			T12_ = (absPath_2.len < relPath_1.len);
			if (T12_) goto LA13_;
			T14_ = (NI)0;
			T14_ = nsuCountString(relPath_1, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_19, NIM_FALSE);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T12_ = (((NI)2) < T14_);
LA13_: ;
			if (!T12_) goto LA15_;
			result = absPath_2;
			eqwasMoved___system_u2688((&absPath_2));
		}
		goto LA10_;
LA15_: ;
		{
			result = relPath_1;
			eqwasMoved___system_u2688((&relPath_1));
		}
LA10_: ;
		eqdestroy___system_u2691(relPath_1);
		eqdestroy___system_u2691(absPath_2);
	}
	break;
	case ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)5):
	{
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)36)))&63U)))!=0)) goto LA21_;
			result = toFilenameOption__msgs_u676(conf_p0, fileIdx_p1, ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA19_;
LA21_: ;
		{
			result = toFilenameOption__msgs_u676(conf_p0, fileIdx_p1, ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)4));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA19_: ;
	}
	break;
	default: __builtin_unreachable();
	}
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toMsgFilename__msgs_u688)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = toFilenameOption__msgs_u676(conf_p0, fileIdx_p1, (*conf_p0).filenameOption);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, addInt__stdZprivateZdigitsutils_u204)(NimStringV2* result_p0, NI x_p1) {
	addInt__stdZprivateZdigitsutils_u187(result_p0, ((NI64) (x_p1)));
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u707)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_11;
	colontmpD_ = toMsgFilename__msgs_u688(conf_p0, info_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
	{
		if (!(((NI)0) < ((NI) (info_p1.line)))) goto LA4_;
		prepareAdd((&result), 1);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_21);
		addInt__stdZprivateZdigitsutils_u204((&result), ((NI) (info_p1.line)));
		{
			if (!(((NI)0) < (NI)(((NI) (info_p1.col)) + ((NI)1)))) goto LA8_;
			prepareAdd((&result), 2);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_23);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)(((NI) (info_p1.col)) + ((NI)1)));
		}
LA8_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_25);
	}
LA4_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, flushDot__msgs_u40)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	FILE* colontmpD_;
	FILE* colontmpD__2;
	tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw colontmpD__3;
	tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw colontmpD__4;
	FILE* stdOrr_1;
	tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw stdOrrKind_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_ = (FILE*)0;
	colontmpD__2 = (FILE*)0;
	colontmpD__3 = (tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0;
	colontmpD__4 = (tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0;
	{
		if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA3_;
		colontmpD_ = stdout;
		stdOrr_1 = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		colontmpD__2 = stderr;
		stdOrr_1 = colontmpD__2;
	}
LA1_: ;
	{
		if (!(stdOrr_1 == stdout)) goto LA8_;
		colontmpD__3 = ((tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0);
		stdOrrKind_1 = colontmpD__3;
	}
	goto LA6_;
LA8_: ;
	{
		colontmpD__4 = ((tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)1);
		stdOrrKind_1 = colontmpD__4;
	}
LA6_: ;
	{
		if (!(((*conf_p0).lastMsgWasDot &((NU8)1<<((NU)((stdOrrKind_1))&7U)))!=0)) goto LA13_;
		(*conf_p0).lastMsgWasDot &= ~(((NU8)1) << (((stdOrrKind_1)) & 7));
		write__stdZsyncio_u254(stdOrr_1, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_30);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
LA13_: ;
	}BeforeRet_: ;
}
static N_INLINE(void, writeLine__msgs_u470)(FILE* f_p0, NimStringV2* x_p1, NI x_p1Len_0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NimStringV2* i_1;
		NI i_2;
		i_1 = (NimStringV2*)0;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < x_p1Len_0)) goto LA3;
				i_1 = (&x_p1[i_2]);
				write__stdZsyncio_u254(f_p0, (*i_1));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA3: ;
		}
	}
	write__stdZsyncio_u254(f_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_31);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, writeContext__msgs_u1111)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastinfo_p1) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	info_1 = lastinfo_p1;
	{
		NI i_1;
		NI colontmp_;
		NI T2_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		T2_ = (*conf_p0).m.msgContext.len;
		colontmp_ = T2_;
		i_2 = ((NI)0);
		{
			while (1) {
				tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ context_1;
				if (!(i_2 < colontmp_)) goto LA4;
				nimZeroMem((void*)(&context_1), sizeof(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ));
				i_1 = i_2;
				eqcopy___lineinfos_u1910((&context_1), (*conf_p0).m.msgContext.p->data[i_1]);
				{
					NIM_BOOL T8_;
					NIM_BOOL T9_;
					NIM_BOOL T11_;
					T8_ = (NIM_BOOL)0;
					T9_ = (NIM_BOOL)0;
					T9_ = eqeq___msgs_u1103(context_1.Field0, lastinfo_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					T8_ = !(T9_);
					if (!(T8_)) goto LA10_;
					T11_ = (NIM_BOOL)0;
					T11_ = eqeq___msgs_u1103(context_1.Field0, info_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					T8_ = !(T11_);
LA10_: ;
					if (!T8_) goto LA12_;
					{
						if (!!(((*conf_p0).structuredErrorHook.ClP_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4.ClP_0 && (*conf_p0).structuredErrorHook.ClE_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4.ClE_0))) goto LA16_;
						(*conf_p0).structuredErrorHook.ClE_0? (*conf_p0).structuredErrorHook.ClP_0(conf_p0, context_1.Field0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6, ((tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA)0), (*conf_p0).structuredErrorHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_7)((*conf_p0).structuredErrorHook.ClP_0))(conf_p0, context_1.Field0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_6, ((tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA)0));
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					}
					goto LA14_;
LA16_: ;
					{
						NimStringV2 message_1;
						NimStringV2 T20_;
						message_1.len = 0; message_1.p = NIM_NIL;
						T20_.len = 0; T20_.p = NIM_NIL;
						{
							if (!(context_1.Field1.len == 0)) goto LA23_;
							message_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_8;
						}
						goto LA21_;
LA23_: ;
						{
							tyArray__YgExxhfgKcesA5EOUj1MOA T26_;
							T26_[0] = context_1.Field1;
							message_1 = nsuFormatVarargs(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_10, T26_, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						}
LA21_: ;
						{
							NimStringV2 colontmpD_;
							NimStringV2 colontmpD__2;
							tyArray__dyW7vpmfeTYw8kX3EXuaJA T32_;
							if (!!(((*conf_p0).writelnHook.ClP_0 == 0))) goto LA29_;
							colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
							colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
							colontmpD_ = toFileLineCol__msgs_u707(conf_p0, context_1.Field0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
							T32_[0] = colontmpD_;
							T32_[1] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_27;
							T32_[2] = message_1;
							colontmpD__2 = concat__msgs_u443(T32_, 3);
							if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
							(*conf_p0).writelnHook.ClE_0? (*conf_p0).writelnHook.ClP_0(colontmpD__2, (*conf_p0).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_28)((*conf_p0).writelnHook.ClP_0))(colontmpD__2);
							if (NIM_UNLIKELY(*nimErr_)) goto LA31_;
							{
								LA31_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__2);
								eqdestroy___system_u2691(colontmpD_);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
						}
						goto LA27_;
LA29_: ;
						{
							if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA36_;
							{
								NimStringV2 colontmpD__3;
								tyArray__dyW7vpmfeTYw8kX3EXuaJA T43_;
								if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)0)))&7U)))!=0)) goto LA40_;
								colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
								flushDot__msgs_u40(conf_p0);
								if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
								colontmpD__3 = toFileLineCol__msgs_u707(conf_p0, context_1.Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
								T43_[0] = colontmpD__3;
								T43_[1] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_32;
								T43_[2] = message_1;
								writeLine__msgs_u470(stdout, T43_, 3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
								flushFile__stdZsyncio_u279(stdout);
								if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
								{
									LA42_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__3);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							}
LA40_: ;
						}
						goto LA27_;
LA36_: ;
						{
							if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)1)))&7U)))!=0)) goto LA47_;
							flushDot__msgs_u40(conf_p0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							{
								NimStringV2 colontmpD__4;
								if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)24)))&63U)))!=0)) goto LA51_;
								colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
								setStyle__pureZterminal_u415(stderr, 1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								colontmpD__4 = toFileLineCol__msgs_u707(conf_p0, context_1.Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								write__stdZsyncio_u254(stderr, colontmpD__4);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								write__stdZsyncio_u254(stderr, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_33);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								resetAttributes__pureZterminal_u376(stderr);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								write__stdZsyncio_u254(stderr, message_1);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								resetAttributes__pureZterminal_u376(stderr);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								write__stdZsyncio_u254(stderr, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_34);
								if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
								{
									LA53_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__4);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							}
							goto LA49_;
LA51_: ;
							{
								NimStringV2 colontmpD__5;
								tyArray__dyW7vpmfeTYw8kX3EXuaJA T58_;
								colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
								colontmpD__5 = toFileLineCol__msgs_u707(conf_p0, context_1.Field0);
								if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
								T58_[0] = colontmpD__5;
								T58_[1] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_35;
								T58_[2] = message_1;
								writeLine__msgs_u470(stderr, T58_, 3);
								if (NIM_UNLIKELY(*nimErr_)) goto LA57_;
								{
									LA57_:;
								}
								{
									eqdestroy___system_u2691(colontmpD__5);
								}
								if (NIM_UNLIKELY(*nimErr_)) goto LA19_;
							}
LA49_: ;
						}
						goto LA27_;
LA47_: ;
LA27_: ;
						{
							LA19_:;
						}
						{
							eqdestroy___system_u2691(message_1);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA5_;
					}
LA14_: ;
				}
LA12_: ;
				info_1 = context_1.Field0;
				i_2 += ((NI)1);
				{
					LA5_:;
				}
				{
					eqdestroy___lineinfos_u1907(context_1);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA4: ;
		}
	}
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, hasWarn__options_u617)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw note_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)13)))&31U)))!=0);
	if (!(T1_)) goto LA2_;
	T1_ = (((*conf_p0).notes[(NU)((note_p1 - 20))>>3] &(1U<<((NU)((note_p1 - 20))&7U)))!=0);
LA2_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, msgKindToString__msgs_u867)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA kind_p0) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), MsgKindToStr__lineinfos_u137[(kind_p0)- 0]);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getMessageStr__msgs_u870)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p0, NimStringV2 arg_p1) {
	NimStringV2 result;
	NimStringV2 colontmpD_;
	tyArray__YgExxhfgKcesA5EOUj1MOA T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD_ = msgKindToString__msgs_u867(msg_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_[0] = arg_p1;
	result = nsuFormatOpenArray(colontmpD_, T2_, 1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, ignoreMsgBecauseOfIdeTools__msgs_u1175)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = (((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17) <= msg_p1);
	if (!(T2_)) goto LA3_;
	T2_ = ((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12));
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = !((((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)33)))&63U)))!=0));
LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, msgWrite__msgs_u844)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw T3_;
		FILE* colontmpD_;
		FILE* colontmpD__2;
		tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw colontmpD__3;
		tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw colontmpD__4;
		FILE* stdOrr_1;
		tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw T11_;
		T3_ = 0;
		if (!!(((*conf_p0).m.errorOutputs == T3_))) goto LA4_;
		colontmpD_ = (FILE*)0;
		colontmpD__2 = (FILE*)0;
		colontmpD__3 = (tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0;
		colontmpD__4 = (tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0;
		{
			if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA8_;
			colontmpD_ = stdout;
			stdOrr_1 = colontmpD_;
		}
		goto LA6_;
LA8_: ;
		{
			colontmpD__2 = stderr;
			stdOrr_1 = colontmpD__2;
		}
LA6_: ;
		write__stdZsyncio_u254(stdOrr_1, s_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		flushFile__stdZsyncio_u279(stdOrr_1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T11_ = (tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0;
		{
			if (!(stdOrr_1 == stdout)) goto LA14_;
			colontmpD__3 = ((tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)0);
			T11_ = colontmpD__3;
		}
		goto LA12_;
LA14_: ;
		{
			colontmpD__4 = ((tyEnum_StdOrrKind__so1PI9cHP1cN622ePtqa0yw)1);
			T11_ = colontmpD__4;
		}
LA12_: ;
		(*conf_p0).lastMsgWasDot |= ((NU8)1)<<(((T11_)) & 7);
	}
LA4_: ;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u4086)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, toFullPathConsiderDirty__msgs_u657)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NimStringV2 colontmpD_;
		NimStringV2 colontmpD__2;
		if (!(fileIdx_p1 < ((NI32)0))) goto LA3_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		{
			NimStringV2 blitTmp_1;
			if (!(fileIdx_p1 == ((NI32)-3))) goto LA7_;
			colontmpD_ = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_55;
			blitTmp_1 = colontmpD_;
			eqwasMoved___system_u2688((&colontmpD_));
			result = blitTmp_1;
		}
		goto LA5_;
LA7_: ;
		{
			NimStringV2 blitTmp_2;
			colontmpD__2 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_56;
			blitTmp_2 = colontmpD__2;
			eqwasMoved___system_u2688((&colontmpD__2));
			result = blitTmp_2;
		}
LA5_: ;
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA3_: ;
	{
		NIM_BOOL T11_;
		T11_ = (NIM_BOOL)0;
		T11_ = isEmpty__options_u4086((*conf_p0).m.fileInfos.p->data[fileIdx_p1].dirtyFile);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!!(T11_)) goto LA12_;
		eqcopy___system_u2694((&result), (*conf_p0).m.fileInfos.p->data[fileIdx_p1].dirtyFile);
	}
	goto LA1_;
LA12_: ;
	{
		eqcopy___system_u2694((&result), (*conf_p0).m.fileInfos.p->data[fileIdx_p1].fullPath);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, addSourceLine__msgs_u1191)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, NimStringV2 line_p2) {
	NimStringV2 colontmpD_;
	colontmpD_ = eqdup___system_u2697(line_p2);
	add__stdZenumutils_u71((&(*conf_p0).m.fileInfos.p->data[fileIdx_p1].lines), colontmpD_);
}
static N_INLINE(NIM_BOOL, isObjDisplayCheck)(TNimTypeV2* source_p0, NI16 targetDepth_p1, NU32 token_p2) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	T1_ = (NIM_BOOL)0;
	T1_ = (targetDepth_p1 <= (*source_p0).depth);
	if (!(T1_)) goto LA2_;
	T1_ = ((*source_p0).display[targetDepth_p1] == token_p2);
LA2_: ;
	result = T1_;
	return result;
}
static N_INLINE(Exception*, nimBorrowCurrentException)(void) {
	Exception* result;
	result = currException__system_u3623;
	return result;
}
static N_INLINE(void, popCurrentException)(void) {
	eqcopy___system_u3656(&currException__system_u3623, (*currException__system_u3623).up, NIM_FALSE);
}
N_LIB_PRIVATE N_NIMCALL(NI, numLines__msgs_u1199)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1) {
	NI result;
	NI T1_;
NIM_BOOL oldNimErrFin11_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	T1_ = (*conf_p0).m.fileInfos.p->data[fileIdx_p1].lines.len;
	result = T1_;
	{
		NI T25_;
		if (!(result == ((NI)0))) goto LA4_;
		{
			NimStringV2 line_1;
			NimStringV2 colontmp_;
			NimStringV2 T9_;
			FILE* f_1;
			FILE* T10_;
			NimStringV2 res_1;
			line_1.len = 0; line_1.p = NIM_NIL;
			colontmp_.len = 0; colontmp_.p = NIM_NIL;
			T9_.len = 0; T9_.p = NIM_NIL;
			T9_ = toFullPathConsiderDirty__msgs_u657(conf_p0, fileIdx_p1);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T9_); goto LA8_;}
			colontmp_ = T9_;
			T10_ = (FILE*)0;
			T10_ = open__stdZsyncio_u493(colontmp_, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)0), ((NI)8000));
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			f_1 = T10_;
			res_1.len = 0; res_1.p = NIM_NIL;
			res_1 = rawNewString(((NI)80));
			{
				while (1) {
					NIM_BOOL T15_;
					T15_ = (NIM_BOOL)0;
					T15_ = readLine__stdZsyncio_u292(f_1, (&res_1));
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
					if (!T15_) goto LA14;
					eqcopy___system_u2694((&line_1), res_1);
					addSourceLine__msgs_u1191(conf_p0, fileIdx_p1, line_1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				} LA14: ;
			}
			{
				LA12_:;
			}
			{
				eqdestroy___system_u2691(res_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA11_;
			{
				LA11_:;
			}
			{
				oldNimErrFin11_ = *nimErr_; *nimErr_ = NIM_FALSE;
				close__stdZsyncio_u269(f_1);
				if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
				*nimErr_ = oldNimErrFin11_;
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA8_;
			{
				LA8_:;
			}
			{
				eqdestroy___system_u2691(colontmp_);
				eqdestroy___system_u2691(line_1);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA6_;
		}
		if (NIM_UNLIKELY(*nimErr_)) {
			LA6_:;
			if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 395251200)) {
				*nimErr_ = NIM_FALSE;
				popCurrentException();
				LA23_:;
			}
		}
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T25_ = (*conf_p0).m.fileInfos.p->data[fileIdx_p1].lines.len;
		result = T25_;
	}
LA4_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, sourceLine__msgs_u1210)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1) {
	NimStringV2 result;
	NI num_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(i_p1.fileIndex < ((NI32)0))) goto LA3_;
		result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_54;
		goto BeforeRet_;
	}
LA3_: ;
	num_1 = numLines__msgs_u1199(conf_p0, i_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		if (!(num_1 < ((NI) (i_p1.line)))) goto LA7_;
		result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_57;
		goto BeforeRet_;
	}
LA7_: ;
	eqcopy___system_u2694((&result), (*conf_p0).m.fileInfos.p->data[i_p1.fileIndex].lines.p->data[(NI)(((NI) (i_p1.line)) - ((NI)1))]);
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, spaces__pureZstrutils_u1139)(NI n_p0) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nsuRepeatChar(32, n_p0);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(void, appendChar)(NimStringV2* dest_p0, NIM_CHAR c_p1) {
	(*(*dest_p0).p).data[(*dest_p0).len] = c_p1;
	(*dest_p0).len += ((NI)1);
	(*(*dest_p0).p).data[(*dest_p0).len] = 0;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getSurroundingSrc__msgs_u1215)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		NIM_BOOL T3_;
		NIM_BOOL T5_;
		NimStringV2 colontmpD_;
		NimStringV2 T8_;
		T3_ = (NIM_BOOL)0;
		T3_ = hasHint__options_u557(conf_p0, ((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)112));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!(T3_)) goto LA4_;
		T5_ = (NIM_BOOL)0;
		T5_ = eqeq___msgs_u1103(info_p1, unknownLineInfo__lineinfos_u364);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T3_ = !(T5_);
LA4_: ;
		if (!T3_) goto LA6_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T8_.len = 0; T8_.p = NIM_NIL;
		colontmpD_ = sourceLine__msgs_u1210(conf_p0, info_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		T8_ = rawNewString(colontmpD_.len + 3);
appendString((&T8_), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_53);
appendString((&T8_), colontmpD_);
		result = T8_;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 colontmpD__3;
			NimStringV2 T13_;
			if (!(((NI16)0) <= info_p1.col)) goto LA11_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			T13_.len = 0; T13_.p = NIM_NIL;
			colontmpD__2 = spaces__pureZstrutils_u1139(((NI) (info_p1.col)));
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			T13_ = rawNewString(colontmpD__2.len + 4);
appendString((&T13_), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_58);
appendString((&T13_), colontmpD__2);
appendChar((&T13_), 94);
			colontmpD__3 = T13_;
			prepareAdd((&result), colontmpD__3.len + 0);
appendString((&result), colontmpD__3);
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
LA11_: ;
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA1_;
LA6_: ;
	{
		result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_59;
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NimStringV2, toFileLineCol__msgs_u701)(tyTuple__kN8up2W6YKc5YA9avn5mV5w* info_p0) {
	NimStringV2 result;
	result = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_62;
	prepareAdd((&result), (*info_p0).Field0.len + 0);
appendString((&result), (*info_p0).Field0);
	{
		if (!(((NI)0) < (*info_p0).Field1)) goto LA3_;
		prepareAdd((&result), 1);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_63);
		addInt__stdZprivateZdigitsutils_u204((&result), (*info_p0).Field1);
		{
			if (!(((NI)0) < (NI)((*info_p0).Field2 + ((NI)1)))) goto LA7_;
			prepareAdd((&result), 2);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_64);
			addInt__stdZprivateZdigitsutils_u204((&result), (NI)((*info_p0).Field2 + ((NI)1)));
		}
LA7_: ;
		prepareAdd((&result), 1);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_65);
	}
LA3_: ;
	return result;
}
static N_INLINE(NimStringV2, slash___stdZprivateZospaths2_u91)(NimStringV2 head_p0, NimStringV2 tail_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = nosjoinPath(head_p0, tail_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, log__msgs_u881)(NimStringV2 s_p0) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	FILE* f_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	f_1 = 0;
	{
		NIM_BOOL T4_;
		tyArray__YgExxhfgKcesA5EOUj1MOA T7_;
		colontmpD_ = nosgetHomeDir();
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		colontmpD__2 = slash___stdZprivateZospaths2_u91(colontmpD_, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_83);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		T4_ = (NIM_BOOL)0;
		T4_ = open__stdZsyncio_u414(&f_1, colontmpD__2, ((tyEnum_FileMode__YkEVJbjDa9aPvYTBr8yiUWg)4), ((NI)-1));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T4_) goto LA5_;
		T7_[0] = s_p0;
		writeLine__msgs_u470(f_1, T7_, 1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		close__stdZsyncio_u269(f_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA5_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(void, quit__system_u7999)(NI errorcode_p0) {
	{
		if (!(errorcode_p0 < ((NI)-128))) goto LA3_;
		exit(((int)-128));
	}
	goto LA1_;
LA3_: ;
	{
		if (!(((NI)127) < errorcode_p0)) goto LA6_;
		exit(((int)127));
	}
	goto LA1_;
LA6_: ;
	{
		exit(((int) (errorcode_p0)));
	}
LA1_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, quit__msgs_u892)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = isDefined__options_u959(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_85);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		if (!T3_) goto LA4_;
		{
			NIM_BOOL T8_;
			NimStringV2 colontmpD_;
			T8_ = (NIM_BOOL)0;
			T8_ = isDefined__options_u959(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_86);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			if (!T8_) goto LA9_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			colontmpD_ = dollar___lineinfos_u134(msg_p1);
			raiseAssert__stdZassertions_u15(colontmpD_);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			eqdestroy___system_u2691(colontmpD_);
		}
		goto LA6_;
LA9_: ;
		{
			NimStringV2 colontmpD__2;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			colontmpD__2 = dollar___lineinfos_u134(msg_p1);
			quit__system_u8018(colontmpD__2, ((NI)1));
			eqdestroy___system_u2691(colontmpD__2);
		}
LA6_: ;
	}
	goto LA1_;
LA4_: ;
	{
		NIM_BOOL T13_;
		NIM_BOOL T14_;
		T13_ = (NIM_BOOL)0;
		T14_ = (NIM_BOOL)0;
		T14_ = NIM_FALSE;
		if (T14_) goto LA15_;
		T14_ = (msg_p1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)2));
LA15_: ;
		T13_ = T14_;
		if (T13_) goto LA16_;
		T13_ = hasHint__options_u557(conf_p0, ((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)114));
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
LA16_: ;
		if (!T13_) goto LA17_;
		{
			NIM_BOOL T21_;
			T21_ = (NIM_BOOL)0;
			T21_ = stackTraceAvailable__system_u4030();
			if (!(T21_)) goto LA22_;
			T21_ = ((*conf_p0).writelnHook.ClP_0 == 0);
LA22_: ;
			if (!T21_) goto LA23_;
			writeStackTrace__system_u2709();
		}
		goto LA19_;
LA23_: ;
		{
			{
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				NimStringV2 colontmpD__5;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T31_;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T32_;
				if (!!(((*conf_p0).writelnHook.ClP_0 == 0))) goto LA28_;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
				T32_[0] = (*conf_p0).command;
				colontmpD__3 = createDocLink__lineinfos_u6(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_90);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				T32_[1] = colontmpD__3;
				colontmpD__4 = nsuFormatOpenArray(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_88, T32_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				T31_[0] = colontmpD__4;
				T31_[1] = (*conf_p0).unitSep;
				colontmpD__5 = concat__msgs_u443(T31_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				(*conf_p0).writelnHook.ClE_0? (*conf_p0).writelnHook.ClP_0(colontmpD__5, (*conf_p0).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_91)((*conf_p0).writelnHook.ClP_0))(colontmpD__5);
				if (NIM_UNLIKELY(*nimErr_)) goto LA30_;
				{
					LA30_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__5);
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
			goto LA26_;
LA28_: ;
			{
				if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA36_;
				{
					NimStringV2 colontmpD__6;
					NimStringV2 colontmpD__7;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T43_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T44_;
					if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)0)))&7U)))!=0)) goto LA40_;
					colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
					colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
					flushDot__msgs_u40(conf_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
					T44_[0] = (*conf_p0).command;
					colontmpD__6 = createDocLink__lineinfos_u6(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_93);
					if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
					T44_[1] = colontmpD__6;
					colontmpD__7 = nsuFormatOpenArray(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_92, T44_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
					T43_[0] = colontmpD__7;
					T43_[1] = (*conf_p0).unitSep;
					writeLine__msgs_u470(stdout, T43_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
					flushFile__stdZsyncio_u279(stdout);
					if (NIM_UNLIKELY(*nimErr_)) goto LA42_;
					{
						LA42_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__7);
						eqdestroy___system_u2691(colontmpD__6);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA40_: ;
			}
			goto LA26_;
LA36_: ;
			{
				if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)1)))&7U)))!=0)) goto LA48_;
				flushDot__msgs_u40(conf_p0);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				{
					NimStringV2 colontmpD__8;
					NimStringV2 colontmpD__9;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T55_;
					if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)24)))&63U)))!=0)) goto LA52_;
					colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
					colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
					setForegroundColor__pureZterminal_u511(stderr, ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)31), NIM_FALSE);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					T55_[0] = (*conf_p0).command;
					colontmpD__8 = createDocLink__lineinfos_u6(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_95);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					T55_[1] = colontmpD__8;
					colontmpD__9 = nsuFormatOpenArray(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_94, T55_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					write__stdZsyncio_u254(stderr, colontmpD__9);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					write__stdZsyncio_u254(stderr, (*conf_p0).unitSep);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					resetAttributes__pureZterminal_u376(stderr);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					write__stdZsyncio_u254(stderr, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_96);
					if (NIM_UNLIKELY(*nimErr_)) goto LA54_;
					{
						LA54_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__9);
						eqdestroy___system_u2691(colontmpD__8);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
				goto LA50_;
LA52_: ;
				{
					NimStringV2 colontmpD__10;
					NimStringV2 colontmpD__11;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T60_;
					tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T61_;
					colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
					colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
					T61_[0] = (*conf_p0).command;
					colontmpD__10 = createDocLink__lineinfos_u6(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_98);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T61_[1] = colontmpD__10;
					colontmpD__11 = nsuFormatOpenArray(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_97, T61_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					T60_[0] = colontmpD__11;
					T60_[1] = (*conf_p0).unitSep;
					writeLine__msgs_u470(stderr, T60_, 2);
					if (NIM_UNLIKELY(*nimErr_)) goto LA59_;
					{
						LA59_:;
					}
					{
						eqdestroy___system_u2691(colontmpD__11);
						eqdestroy___system_u2691(colontmpD__10);
					}
					if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				}
LA50_: ;
			}
			goto LA26_;
LA48_: ;
LA26_: ;
		}
LA19_: ;
	}
	goto LA1_;
LA17_: ;
LA1_: ;
	quit__system_u7999(((NI)1));
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, handleError__msgs_u964)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p1, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p2, NimStringV2 s_p3, NIM_BOOL ignoreMsg_p4) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(msg_p1 >= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0) && msg_p1 <= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)2))) goto LA3_;
		{
			if (!((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12))) goto LA7_;
			log__msgs_u881(s_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA7_: ;
		{
			NIM_BOOL T11_;
			T11_ = (NIM_BOOL)0;
			T11_ = !(((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12)));
			if (T11_) goto LA12_;
			T11_ = !((msg_p1 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)1)));
LA12_: ;
			if (!T11_) goto LA13_;
			quit__msgs_u892(conf_p0, msg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA13_: ;
	}
LA3_: ;
	{
		NIM_BOOL T17_;
		NIM_BOOL T18_;
		NIM_BOOL T21_;
		NIM_BOOL T22_;
		tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg T23_;
		T17_ = (NIM_BOOL)0;
		T18_ = (NIM_BOOL)0;
		T18_ = (((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0) <= msg_p1);
		if (!(T18_)) goto LA19_;
		T18_ = (msg_p1 <= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19));
LA19_: ;
		T17_ = T18_;
		if (T17_) goto LA20_;
		T21_ = (NIM_BOOL)0;
		T22_ = (NIM_BOOL)0;
		T23_ = dotdot___msgs_u994(((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)20), ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)123));
		T22_ = contains__msgs_u1062(T23_, msg_p1);
		if (!(T22_)) goto LA24_;
		T22_ = (((*conf_p0).warningAsErrors[(NU)(((msg_p1) - 20))>>3] &(1U<<((NU)(((msg_p1) - 20))&7U)))!=0);
LA24_: ;
		T21_ = T22_;
		if (!(T21_)) goto LA25_;
		T21_ = !(ignoreMsg_p4);
LA25_: ;
		T17_ = T21_;
LA20_: ;
		if (!T17_) goto LA26_;
		(*conf_p0).errorCounter += ((NI)1);
		(*conf_p0).exitcode = ((NI8)1);
		{
			if (!((*conf_p0).errorMax <= (*conf_p0).errorCounter)) goto LA30_;
			{
				if (!((*conf_p0).ideCmd == ((tyEnum_IdeCmd__mZiSMTDWSAKKDbZfXDQwng)0))) goto LA34_;
				quit__msgs_u892(conf_p0, msg_p1);
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			}
LA34_: ;
		}
		goto LA28_;
LA30_: ;
		{
			NIM_BOOL T37_;
			T37_ = (NIM_BOOL)0;
			T37_ = (eh_p2 == ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1));
			if (!(T37_)) goto LA38_;
			T37_ = !(((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12)));
LA38_: ;
			if (!T37_) goto LA39_;
			quit__msgs_u892(conf_p0, msg_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA28_;
LA39_: ;
		{
			if (!(eh_p2 == ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)2))) goto LA42_;
			raiseRecoverableError__lineinfos_u299(s_p3);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA28_;
LA42_: ;
LA28_: ;
	}
LA26_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NOINLINE(void, liMessage__msgs_u1227)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3, tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w eh_p4, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p5, NIM_BOOL isRaw_p6, NIM_BOOL ignoreError_p7) {
	NimStringV2 title_1;
	NimStringV2 kind_1;
	NimStringV2 s_1;
	tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg color_1;
	NIM_BOOL ignoreMsg_1;
	tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA sev_1;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputsOld_1;
	NimStringV2 T6_;
	NimStringV2 T43_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	title_1.len = 0; title_1.p = NIM_NIL;
	kind_1.len = 0; kind_1.p = NIM_NIL;
	s_1.len = 0; s_1.p = NIM_NIL;
	color_1 = (tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)0;
	ignoreMsg_1 = NIM_FALSE;
	sev_1 = (tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA)0;
	errorOutputsOld_1 = (*conf_p0).m.errorOutputs;
	{
		if (!(msg_p2 >= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0) && msg_p2 <= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)2))) goto LA4_;
		(*conf_p0).m.errorOutputs = 3;
	}
LA4_: ;
	T6_.len = 0; T6_.p = NIM_NIL;
	{
		NIM_BOOL T9_;
		tyObject_HSlice__JK89bK9aJ8k4LQG5jYx7EgOg T10_;
		T9_ = (NIM_BOOL)0;
		T10_ = dotdot___msgs_u994(((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)20), ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)123));
		T9_ = contains__msgs_u1062(T10_, msg_p2);
		if (!(T9_)) goto LA11_;
		T9_ = !((msg_p2 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)119)));
LA11_: ;
		if (!T9_) goto LA12_;
		kind_1 = dollar___lineinfos_u134(msg_p2);
	}
	goto LA7_;
LA12_: ;
	{
		kind_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_3;
	}
LA7_: ;
	switch (msg_p2) {
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0) ... ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19):
	{
		sev_1 = ((tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA)2);
		writeContext__msgs_u1111(conf_p0, info_p1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_37;
		color_1 = ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)31);
		{
			NIM_BOOL T18_;
			T18_ = (NIM_BOOL)0;
			T18_ = eqeq___msgs_u1103(info_p1, unknownLineInfo__lineinfos_u364);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			if (!!(T18_)) goto LA19_;
			(*conf_p0).m.lastError = info_p1;
		}
LA19_: ;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)20) ... ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)88):
	{
		NIM_BOOL T22_;
		sev_1 = ((tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA)1);
		T22_ = (NIM_BOOL)0;
		T22_ = hasWarn__options_u617(conf_p0, (msg_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		ignoreMsg_1 = !(T22_);
		{
			NIM_BOOL T25_;
			T25_ = (NIM_BOOL)0;
			T25_ = !(ignoreMsg_1);
			if (!(T25_)) goto LA26_;
			T25_ = (((*conf_p0).warningAsErrors[(NU)(((msg_p2) - 20))>>3] &(1U<<((NU)(((msg_p2) - 20))&7U)))!=0);
LA26_: ;
			if (!T25_) goto LA27_;
			title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_38;
			color_1 = ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)31);
		}
		goto LA23_;
LA27_: ;
		{
			title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_40;
			color_1 = ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)33);
		}
LA23_: ;
		{
			if (!!(ignoreMsg_1)) goto LA32_;
			writeContext__msgs_u1111(conf_p0, info_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA32_: ;
		(*conf_p0).warnCounter += ((NI)1);
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)89) ... ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)123):
	{
		NIM_BOOL T35_;
		sev_1 = ((tyEnum_Severity__mHEDvws7FmOtnFhcQsM8UA)0);
		T35_ = (NIM_BOOL)0;
		T35_ = hasHint__options_u557(conf_p0, (msg_p2));
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		ignoreMsg_1 = !(T35_);
		{
			NIM_BOOL T38_;
			T38_ = (NIM_BOOL)0;
			T38_ = !(ignoreMsg_1);
			if (!(T38_)) goto LA39_;
			T38_ = (((*conf_p0).warningAsErrors[(NU)(((msg_p2) - 20))>>3] &(1U<<((NU)(((msg_p2) - 20))&7U)))!=0);
LA39_: ;
			if (!T38_) goto LA40_;
			title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_41;
			color_1 = ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)31);
		}
		goto LA36_;
LA40_: ;
		{
			title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_43;
			color_1 = ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)32);
		}
LA36_: ;
		(*conf_p0).hintCounter += ((NI)1);
	}
	break;
	default: __builtin_unreachable();
	}
	T43_.len = 0; T43_.p = NIM_NIL;
	{
		if (!isRaw_p6) goto LA46_;
		eqcopy___system_u2694((&s_1), arg_p3);
	}
	goto LA44_;
LA46_: ;
	{
		s_1 = getMessageStr__msgs_u870(msg_p2, arg_p3);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA44_: ;
	{
		NimStringV2 loc_1;
		NimStringV2 kindmsg_1;
		NimStringV2 T54_;
		NimStringV2 T65_;
		if (!!(ignoreMsg_1)) goto LA51_;
		loc_1.len = 0; loc_1.p = NIM_NIL;
		kindmsg_1.len = 0; kindmsg_1.p = NIM_NIL;
		T54_.len = 0; T54_.p = NIM_NIL;
		{
			NIM_BOOL T57_;
			NimStringV2 colontmpD_;
			NimStringV2 T61_;
			T57_ = (NIM_BOOL)0;
			T57_ = eqeq___msgs_u1103(info_p1, unknownLineInfo__lineinfos_u364);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			if (!!(T57_)) goto LA58_;
			colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
			T61_.len = 0; T61_.p = NIM_NIL;
			colontmpD_ = toFileLineCol__msgs_u707(conf_p0, info_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA60_;
			T61_ = rawNewString(colontmpD_.len + 1);
appendString((&T61_), colontmpD_);
appendString((&T61_), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_44);
			loc_1 = T61_;
			{
				LA60_:;
			}
			{
				eqdestroy___system_u2691(colontmpD_);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		}
		goto LA55_;
LA58_: ;
		{
			loc_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_45;
		}
LA55_: ;
		T65_.len = 0; T65_.p = NIM_NIL;
		{
			if (!(((NI)0) < kind_1.len)) goto LA68_;
			kindmsg_1 = nsuFormatSingleElem(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_47, kind_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
		}
		goto LA66_;
LA68_: ;
		{
			kindmsg_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_48;
		}
LA66_: ;
		{
			NimStringV2 colontmpD__2;
			NimStringV2 T75_;
			if (!!(((*conf_p0).structuredErrorHook.ClP_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4.ClP_0 && (*conf_p0).structuredErrorHook.ClE_0 == TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_4.ClE_0))) goto LA73_;
			colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
			T75_.len = 0; T75_.p = NIM_NIL;
			T75_ = rawNewString(s_1.len + kindmsg_1.len + 0);
appendString((&T75_), s_1);
appendString((&T75_), kindmsg_1);
			colontmpD__2 = T75_;
			(*conf_p0).structuredErrorHook.ClE_0? (*conf_p0).structuredErrorHook.ClP_0(conf_p0, info_p1, colontmpD__2, sev_1, (*conf_p0).structuredErrorHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_49)((*conf_p0).structuredErrorHook.ClP_0))(conf_p0, info_p1, colontmpD__2, sev_1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			eqdestroy___system_u2691(colontmpD__2);
		}
LA73_: ;
		{
			NIM_BOOL T78_;
			T78_ = (NIM_BOOL)0;
			T78_ = ignoreMsgBecauseOfIdeTools__msgs_u1175(conf_p0, msg_p2);
			if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			if (!!(T78_)) goto LA79_;
			{
				NIM_BOOL T83_;
				T83_ = (NIM_BOOL)0;
				T83_ = (msg_p2 == ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)99));
				if (!(T83_)) goto LA84_;
				T83_ = (*conf_p0).hintProcessingDots;
LA84_: ;
				if (!T83_) goto LA85_;
				msgWrite__msgs_u844(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_51);
				if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
			}
			goto LA81_;
LA85_: ;
			{
				{
					NimStringV2 colontmpD__3;
					NimStringV2 colontmpD__4;
					tyArray__A2YC0h9cZydgH7zGAndH9bLg T92_;
					if (!!(((*conf_p0).writelnHook.ClP_0 == 0))) goto LA90_;
					colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
					colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
					T92_[0] = loc_1;
					T92_[1] = title_1;
					T92_[2] = s_1;
					T92_[3] = kindmsg_1;
					colontmpD__3 = getSurroundingSrc__msgs_u1215(conf_p0, info_p1);
					if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					T92_[4] = colontmpD__3;
					T92_[5] = (*conf_p0).unitSep;
					colontmpD__4 = concat__msgs_u443(T92_, 6);
					if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					(*conf_p0).writelnHook.ClE_0? (*conf_p0).writelnHook.ClP_0(colontmpD__4, (*conf_p0).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_60)((*conf_p0).writelnHook.ClP_0))(colontmpD__4);
					if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
				}
				goto LA88_;
LA90_: ;
				{
					if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA94_;
					{
						NimStringV2 colontmpD__5;
						tyArray__A2YC0h9cZydgH7zGAndH9bLg T101_;
						if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)0)))&7U)))!=0)) goto LA98_;
						colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
						flushDot__msgs_u40(conf_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
						T101_[0] = loc_1;
						T101_[1] = title_1;
						T101_[2] = s_1;
						T101_[3] = kindmsg_1;
						colontmpD__5 = getSurroundingSrc__msgs_u1215(conf_p0, info_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
						T101_[4] = colontmpD__5;
						T101_[5] = (*conf_p0).unitSep;
						writeLine__msgs_u470(stdout, T101_, 6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
						flushFile__stdZsyncio_u279(stdout);
						if (NIM_UNLIKELY(*nimErr_)) goto LA100_;
						{
							LA100_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__5);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					}
LA98_: ;
				}
				goto LA88_;
LA94_: ;
				{
					if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)1)))&7U)))!=0)) goto LA105_;
					flushDot__msgs_u40(conf_p0);
					if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					{
						NimStringV2 colontmpD__6;
						if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)24)))&63U)))!=0)) goto LA109_;
						colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
						setStyle__pureZterminal_u415(stderr, 1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, loc_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						resetAttributes__pureZterminal_u376(stderr);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						setForegroundColor__pureZterminal_u511(stderr, color_1, NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, title_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						resetAttributes__pureZterminal_u376(stderr);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, s_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						setForegroundColor__pureZterminal_u511(stderr, ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)36), NIM_FALSE);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, kindmsg_1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						resetAttributes__pureZterminal_u376(stderr);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						colontmpD__6 = getSurroundingSrc__msgs_u1215(conf_p0, info_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, colontmpD__6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, (*conf_p0).unitSep);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						resetAttributes__pureZterminal_u376(stderr);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						write__stdZsyncio_u254(stderr, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_61);
						if (NIM_UNLIKELY(*nimErr_)) goto LA111_;
						{
							LA111_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__6);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					}
					goto LA107_;
LA109_: ;
					{
						NimStringV2 colontmpD__7;
						tyArray__A2YC0h9cZydgH7zGAndH9bLg T116_;
						colontmpD__7.len = 0; colontmpD__7.p = NIM_NIL;
						T116_[0] = loc_1;
						T116_[1] = title_1;
						T116_[2] = s_1;
						T116_[3] = kindmsg_1;
						colontmpD__7 = getSurroundingSrc__msgs_u1215(conf_p0, info_p1);
						if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
						T116_[4] = colontmpD__7;
						T116_[5] = (*conf_p0).unitSep;
						writeLine__msgs_u470(stderr, T116_, 6);
						if (NIM_UNLIKELY(*nimErr_)) goto LA115_;
						{
							LA115_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__7);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					}
LA107_: ;
				}
				goto LA88_;
LA105_: ;
LA88_: ;
				{
					if (!(((*conf_p0).mainPackageNotes[(NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)122) - 20))>>3] &(1U<<((NU)((((tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw)122) - 20))&7U)))!=0)) goto LA121_;
					{
						NimStringV2 colontmpD__8;
						NimStringV2 colontmpD__9;
						NimStringV2 colontmpD__10;
						tyArray__Seu7uK9aaOSN0BK3EAjjSHw T128_;
						if (!!(((*conf_p0).writelnHook.ClP_0 == 0))) goto LA125_;
						colontmpD__8.len = 0; colontmpD__8.p = NIM_NIL;
						colontmpD__9.len = 0; colontmpD__9.p = NIM_NIL;
						colontmpD__10.len = 0; colontmpD__10.p = NIM_NIL;
						colontmpD__8 = toFileLineCol__msgs_u701(info2_p5);
						if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
						T128_[0] = colontmpD__8;
						T128_[1] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_67;
						colontmpD__9 = nsuFormatSingleElem(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_68, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_70);
						if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
						T128_[2] = colontmpD__9;
						T128_[3] = (*conf_p0).unitSep;
						colontmpD__10 = concat__msgs_u443(T128_, 4);
						if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
						(*conf_p0).writelnHook.ClE_0? (*conf_p0).writelnHook.ClP_0(colontmpD__10, (*conf_p0).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_71)((*conf_p0).writelnHook.ClP_0))(colontmpD__10);
						if (NIM_UNLIKELY(*nimErr_)) goto LA127_;
						{
							LA127_:;
						}
						{
							eqdestroy___system_u2691(colontmpD__10);
							eqdestroy___system_u2691(colontmpD__9);
							eqdestroy___system_u2691(colontmpD__8);
						}
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
					}
					goto LA123_;
LA125_: ;
					{
						if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA132_;
						{
							NimStringV2 colontmpD__11;
							NimStringV2 colontmpD__12;
							tyArray__Seu7uK9aaOSN0BK3EAjjSHw T139_;
							if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)0)))&7U)))!=0)) goto LA136_;
							colontmpD__11.len = 0; colontmpD__11.p = NIM_NIL;
							colontmpD__12.len = 0; colontmpD__12.p = NIM_NIL;
							flushDot__msgs_u40(conf_p0);
							if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
							colontmpD__11 = toFileLineCol__msgs_u701(info2_p5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
							T139_[0] = colontmpD__11;
							T139_[1] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_72;
							colontmpD__12 = nsuFormatSingleElem(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_73, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_74);
							if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
							T139_[2] = colontmpD__12;
							T139_[3] = (*conf_p0).unitSep;
							writeLine__msgs_u470(stdout, T139_, 4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
							flushFile__stdZsyncio_u279(stdout);
							if (NIM_UNLIKELY(*nimErr_)) goto LA138_;
							{
								LA138_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__12);
								eqdestroy___system_u2691(colontmpD__11);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						}
LA136_: ;
					}
					goto LA123_;
LA132_: ;
					{
						if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)1)))&7U)))!=0)) goto LA143_;
						flushDot__msgs_u40(conf_p0);
						if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						{
							NimStringV2 colontmpD__13;
							NimStringV2 colontmpD__14;
							if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)24)))&63U)))!=0)) goto LA147_;
							colontmpD__13.len = 0; colontmpD__13.p = NIM_NIL;
							colontmpD__14.len = 0; colontmpD__14.p = NIM_NIL;
							setStyle__pureZterminal_u415(stderr, 1);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							colontmpD__13 = toFileLineCol__msgs_u701(info2_p5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							write__stdZsyncio_u254(stderr, colontmpD__13);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							resetAttributes__pureZterminal_u376(stderr);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							write__stdZsyncio_u254(stderr, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_75);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							setForegroundColor__pureZterminal_u511(stderr, ((tyEnum_ForegroundColor__prdrXkAw6H7iUBRVoWE3cg)36), NIM_FALSE);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							colontmpD__14 = nsuFormatSingleElem(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_76, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_77);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							write__stdZsyncio_u254(stderr, colontmpD__14);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							resetAttributes__pureZterminal_u376(stderr);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							write__stdZsyncio_u254(stderr, (*conf_p0).unitSep);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							resetAttributes__pureZterminal_u376(stderr);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							write__stdZsyncio_u254(stderr, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_78);
							if (NIM_UNLIKELY(*nimErr_)) goto LA149_;
							{
								LA149_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__14);
								eqdestroy___system_u2691(colontmpD__13);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						}
						goto LA145_;
LA147_: ;
						{
							NimStringV2 colontmpD__15;
							NimStringV2 colontmpD__16;
							tyArray__Seu7uK9aaOSN0BK3EAjjSHw T154_;
							colontmpD__15.len = 0; colontmpD__15.p = NIM_NIL;
							colontmpD__16.len = 0; colontmpD__16.p = NIM_NIL;
							colontmpD__15 = toFileLineCol__msgs_u701(info2_p5);
							if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
							T154_[0] = colontmpD__15;
							T154_[1] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_79;
							colontmpD__16 = nsuFormatSingleElem(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_80, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_81);
							if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
							T154_[2] = colontmpD__16;
							T154_[3] = (*conf_p0).unitSep;
							writeLine__msgs_u470(stderr, T154_, 4);
							if (NIM_UNLIKELY(*nimErr_)) goto LA153_;
							{
								LA153_:;
							}
							{
								eqdestroy___system_u2691(colontmpD__16);
								eqdestroy___system_u2691(colontmpD__15);
							}
							if (NIM_UNLIKELY(*nimErr_)) goto LA53_;
						}
LA145_: ;
					}
					goto LA123_;
LA143_: ;
LA123_: ;
				}
LA121_: ;
			}
LA81_: ;
		}
LA79_: ;
		{
			LA53_:;
		}
		{
			eqdestroy___system_u2691(kindmsg_1);
			eqdestroy___system_u2691(loc_1);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA51_: ;
	{
		if (!!(ignoreError_p7)) goto LA161_;
		handleError__msgs_u964(conf_p0, msg_p2, eh_p4, s_1, ignoreMsg_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA161_: ;
	{
		if (!(msg_p2 >= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0) && msg_p2 <= ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)2))) goto LA165_;
		(*conf_p0).m.errorOutputs = errorOutputsOld_1;
	}
LA165_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(s_1);
		eqdestroy___system_u2691(kind_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, msgWriteln__msgs_u737)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1, tySet_tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw flags_p2) {
	NimStringV2 sep_1;
	NimStringV2 T2_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	sep_1.len = 0; sep_1.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	{
		if (!!(((flags_p2 &((NU8)1<<((NU)((((tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw)2)))&7U)))!=0))) goto LA5_;
		eqcopy___system_u2694((&sep_1), (*conf_p0).unitSep);
	}
	goto LA3_;
LA5_: ;
	{
		sep_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_99;
	}
LA3_: ;
	{
		NIM_BOOL T10_;
		NimStringV2 colontmpD_;
		NimStringV2 T14_;
		T10_ = (NIM_BOOL)0;
		T10_ = !(((*conf_p0).writelnHook.ClP_0 == 0));
		if (!(T10_)) goto LA11_;
		T10_ = !(((flags_p2 &((NU8)1<<((NU)((((tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw)1)))&7U)))!=0));
LA11_: ;
		if (!T10_) goto LA12_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T14_.len = 0; T14_.p = NIM_NIL;
		T14_ = rawNewString(s_p1.len + sep_1.len + 0);
appendString((&T14_), s_p1);
appendString((&T14_), sep_1);
		colontmpD_ = T14_;
		(*conf_p0).writelnHook.ClE_0? (*conf_p0).writelnHook.ClP_0(colontmpD_, (*conf_p0).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_100)((*conf_p0).writelnHook.ClP_0))(colontmpD_);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		eqdestroy___system_u2691(colontmpD_);
	}
	goto LA8_;
LA12_: ;
	{
		NIM_BOOL T16_;
		T16_ = (NIM_BOOL)0;
		T16_ = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0);
		if (T16_) goto LA17_;
		T16_ = ((flags_p2 &((NU8)1<<((NU)((((tyEnum_MsgFlag__uOe9ahJyFezfCR4dA8VRyQw)0)))&7U)))!=0);
LA17_: ;
		if (!T16_) goto LA18_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T24_;
			if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)0)))&7U)))!=0)) goto LA22_;
			flushDot__msgs_u40(conf_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			write__stdZsyncio_u254(stdout, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T24_[0] = sep_1;
			writeLine__msgs_u470(stdout, T24_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			flushFile__stdZsyncio_u279(stdout);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA22_: ;
	}
	goto LA8_;
LA18_: ;
	{
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T30_;
			if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)1)))&7U)))!=0)) goto LA28_;
			flushDot__msgs_u40(conf_p0);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			write__stdZsyncio_u254(stderr, s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
			T30_[0] = sep_1;
			writeLine__msgs_u470(stderr, T30_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
LA28_: ;
	}
LA8_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(sep_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listWarnings__msgs_u1646)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	msgWriteln__msgs_u737(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_102, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA aX60gensym130__1;
		NI res_1;
		aX60gensym130__1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		res_1 = ((NI)20);
		{
			while (1) {
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T5_;
				if (!(res_1 <= ((NI)88))) goto LA3;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				aX60gensym130__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (res_1));
				{
					if (!(((*conf_p0).notes[(NU)(((aX60gensym130__1) - 20))>>3] &(1U<<((NU)(((aX60gensym130__1) - 20))&7U)))!=0)) goto LA8_;
					colontmpD_ = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_106;
					T5_[0] = colontmpD_;
				}
				goto LA6_;
LA8_: ;
				{
					colontmpD__2 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_107;
					T5_[0] = colontmpD__2;
				}
LA6_: ;
				colontmpD__3 = dollar___lineinfos_u134(aX60gensym130__1);
				T5_[1] = colontmpD__3;
				colontmpD__4 = nsuFormatOpenArray(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_104, T5_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				msgWriteln__msgs_u737(conf_p0, colontmpD__4, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				res_1 += ((NI)1);
				{
					LA4_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, listHints__msgs_u1668)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	msgWriteln__msgs_u737(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_109, 4);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	{
		tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA aX60gensym132__1;
		NI res_1;
		aX60gensym132__1 = (tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0;
		res_1 = ((NI)89);
		{
			while (1) {
				NimStringV2 colontmpD_;
				NimStringV2 colontmpD__2;
				NimStringV2 colontmpD__3;
				NimStringV2 colontmpD__4;
				tyArray__pK4u9cQ1bJzH46rrmNu9bPMQ T5_;
				if (!(res_1 <= ((NI)123))) goto LA3;
				colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
				colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
				colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
				colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
				aX60gensym132__1 = ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA) (res_1));
				{
					if (!(((*conf_p0).notes[(NU)(((aX60gensym132__1) - 20))>>3] &(1U<<((NU)(((aX60gensym132__1) - 20))&7U)))!=0)) goto LA8_;
					colontmpD_ = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_111;
					T5_[0] = colontmpD_;
				}
				goto LA6_;
LA8_: ;
				{
					colontmpD__2 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_112;
					T5_[0] = colontmpD__2;
				}
LA6_: ;
				colontmpD__3 = dollar___lineinfos_u134(aX60gensym132__1);
				T5_[1] = colontmpD__3;
				colontmpD__4 = nsuFormatOpenArray(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_110, T5_, 2);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				msgWriteln__msgs_u737(conf_p0, colontmpD__4, 4);
				if (NIM_UNLIKELY(*nimErr_)) goto LA4_;
				res_1 += ((NI)1);
				{
					LA4_:;
				}
				{
					eqdestroy___system_u2691(colontmpD__4);
					eqdestroy___system_u2691(colontmpD__3);
					eqdestroy___system_u2691(colontmpD__2);
					eqdestroy___system_u2691(colontmpD_);
				}
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			} LA3: ;
		}
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, msgQuit__msgs_u479)(NI8 x_p0) {
	quit__system_u7999(((NI) (x_p0)));
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, newLineInfo__msgs_u419)(NI32 fileInfoIdx_p0, NI line_p1, NI col_p2) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	result.fileIndex = fileInfoIdx_p0;
	{
		if (!(line_p1 < ((NI)65535))) goto LA3_;
		result.line = ((NU16) (line_p1));
	}
	goto LA1_;
LA3_: ;
	{
		result.line = ((NU16)65535);
	}
LA1_: ;
	{
		if (!(col_p2 < ((NI)32767))) goto LA8_;
		result.col = ((NI16) (col_p2));
	}
	goto LA6_;
LA8_: ;
	{
		result.col = ((NI16)-1);
	}
LA6_: ;
	return result;
}
static N_INLINE(void, canonicalCase__msgs_u99)(NimStringV2* path_p0) {
}
static N_INLINE(NF, toFloat__system_u1695)(NI i_p0) {
	NF result;
	result = ((NF) (i_p0));
	return result;
}
static N_INLINE(void, nimAddCharV1)(NimStringV2* s_p0, NIM_CHAR c_p1) {
	prepareAdd(s_p0, ((NI)1));
	(*(*s_p0).p).data[(*s_p0).len] = c_p1;
	(*s_p0).len += ((NI)1);
	(*(*s_p0).p).data[(*s_p0).len] = 0;
}
static N_INLINE(void, toCChar__msgs_u80)(NIM_CHAR c_p0, NimStringV2* result_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	switch (((NU8)(c_p0))) {
	case 0 ... 31:
	case 127 ... 255:
	{
		NimStringV2 colontmpD_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		nimAddCharV1((&(*result_p1)), 92);
		colontmpD_ = nsuToOctal(c_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		prepareAdd((&(*result_p1)), colontmpD_.len + 0);
appendString((&(*result_p1)), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
	break;
	case 39:
	case 34:
	case 92:
	case 63:
	{
		nimAddCharV1((&(*result_p1)), 92);
		nimAddCharV1((&(*result_p1)), c_p0);
	}
	break;
	default:
	{
		nimAddCharV1((&(*result_p1)), c_p0);
	}
	break;
	}
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, makeCString__msgs_u83)(NimStringV2 s_p0) {
	NimStringV2 result;
	NF T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	T1_ = (NF)0;
	T1_ = toFloat__system_u1695(s_p0.len);
	result = rawNewString(((NI)((((NI) (((NF)(T1_) * (NF)(1.1))))) + ((NI)1))));
	prepareAdd((&result), 1);
appendString((&result), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_114);
	{
		NI i_1;
		NI colontmp_;
		NI i_2;
		i_1 = (NI)0;
		colontmp_ = (NI)0;
		colontmp_ = s_p0.len;
		i_2 = ((NI)0);
		{
			while (1) {
				if (!(i_2 < colontmp_)) goto LA4;
				i_1 = i_2;
				toCChar__msgs_u80(s_p0.p->data[i_1], (&result));
				if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
				i_2 += ((NI)1);
			} LA4: ;
		}
	}
	nimAddCharV1((&result), 34);
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, newFileInfo__msgs_u91)(NimStringV2 fullPath_p0, NimStringV2 projPath_p1, tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw* Result) {
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T1_;
	NimStringV2 T2_;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw));
	nimZeroMem((void*)Result, sizeof(tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw));
	colontmpD_ = eqdup___system_u2697(fullPath_p0);
	(*Result).fullPath = colontmpD_;
	colontmpD__2 = eqdup___system_u2697(projPath_p1);
	(*Result).projPath = colontmpD__2;
	T1_.len = 0; T1_.p = NIM_NIL;
	T1_ = nosextractFilename(fullPath_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T1_); goto BeforeRet_;}
	(*Result).shortName = T1_;
	T2_.len = 0; T2_.p = NIM_NIL;
	T2_ = makeCString__msgs_u83(fullPath_p0);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T2_); goto BeforeRet_;}
	(*Result).quotedFullName = T2_;
	(*Result).lines.len = 0; (*Result).lines.p = (tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content*) newSeqPayload(0, sizeof(NimStringV2), NIM_ALIGNOF(NimStringV2));
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = makeCString__msgs_u83((*Result).shortName);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto BeforeRet_;}
	eqsink___system_u2700((&(*Result).quotedName), T3_);
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u155)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1, NIM_BOOL* isKnownFile_p2) {
	NI32 result;
	NimStringV2 canon_1;
	NimStringV2 canon2_1;
	NimStringV2 colontmpD_;
	NIM_BOOL pseudoPath_1;
	NimStringV2 T3_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	canon_1.len = 0; canon_1.p = NIM_NIL;
	canon2_1.len = 0; canon2_1.p = NIM_NIL;
	pseudoPath_1 = NIM_FALSE;
	T3_.len = 0; T3_.p = NIM_NIL;
	T3_ = canonicalizePath__options_u3669(conf_p0, filename_p1);
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T3_); goto LA2_;}
	canon_1 = T3_;
	if (NIM_UNLIKELY(*nimErr_)) {
		LA2_:;
		if (isObjDisplayCheck(nimBorrowCurrentException()->Sup.m_type, 3, 3796386048)) {
			*nimErr_ = NIM_FALSE;
			eqcopy___system_u2694((&canon_1), filename_p1);
			pseudoPath_1 = NIM_TRUE;
			popCurrentException();
			LA5_:;
		}
	}
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD_ = eqdup___system_u2697(canon_1);
	canon2_1 = colontmpD_;
	canonicalCase__msgs_u99((&canon2_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		NIM_BOOL T9_;
		NI32* T12_;
		T9_ = (NIM_BOOL)0;
		T9_ = hasKey__msgs_u142((*conf_p0).m.filenameToIndexTbl, canon2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!T9_) goto LA10_;
		(*isKnownFile_p2) = NIM_TRUE;
		T12_ = (NI32*)0;
		T12_ = X5BX5D___msgs_u253((&(*conf_p0).m.filenameToIndexTbl), canon2_1);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		result = (*T12_);
	}
	goto LA7_;
LA10_: ;
	{
		NimStringV2 colontmpD__2;
		NimStringV2 colontmpD__3;
		NI T15_;
		NimStringV2 T16_;
		tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw T26_;
		colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
		colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
		(*isKnownFile_p2) = NIM_FALSE;
		T15_ = (*conf_p0).m.fileInfos.len;
		result = ((NI32) (T15_));
		T16_.len = 0; T16_.p = NIM_NIL;
		{
			NimStringV2 colontmpD__4;
			if (!pseudoPath_1) goto LA19_;
			colontmpD__4 = eqdup___system_u2697(filename_p1);
			colontmpD__2 = colontmpD__4;
			T16_ = colontmpD__2;
		}
		goto LA17_;
LA19_: ;
		{
			NimStringV2 T23_;
			T23_.len = 0; T23_.p = NIM_NIL;
			T23_ = relativeTo__pathutils_u196(canon_1, (*conf_p0).projectPath, 47);
			if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T23_); goto LA22_;}
			colontmpD__3 = T23_;
			T16_ = colontmpD__3;
			{
				LA22_:;
			}
			{
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		}
LA17_: ;
		nimZeroMem((void*)(&T26_), sizeof(tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw));
		newFileInfo__msgs_u91(canon_1, T16_, (&T26_));
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		add__msgs_u342((&(*conf_p0).m.fileInfos), (&T26_));
		X5BX5Deq___lineinfos_u646((&(*conf_p0).m.filenameToIndexTbl), canon2_1, result);
		if (NIM_UNLIKELY(*nimErr_)) goto LA14_;
		{
			LA14_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__3);
			eqdestroy___system_u2691(colontmpD__2);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA7_: ;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(canon2_1);
		eqdestroy___system_u2691(canon_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u404)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1) {
	NI32 result;
	NIM_BOOL dummy_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	dummy_1 = NIM_FALSE;
	result = fileInfoIdx__msgs_u155(conf_p0, filename_p1, (&dummy_1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setDirtyFile__msgs_u632)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, NimStringV2 filename_p2) {
	eqcopy___system_u2694((&(*conf_p0).m.fileInfos.p->data[fileIdx_p1].dirtyFile), filename_p2);
	setLen__system_u5431((&(*conf_p0).m.fileInfos.p->data[fileIdx_p1].lines), ((NI)0));
}
N_LIB_PRIVATE N_NIMCALL(void, internalErrorImpl__msgs_u1598)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 errMsg_p2, tyTuple__kN8up2W6YKc5YA9avn5mV5w* info2_p3) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = ((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)12) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)8));
		if (!(T3_)) goto LA4_;
		T3_ = ((*conf_p0).structuredErrorHook.ClP_0 == 0);
LA4_: ;
		if (!T3_) goto LA5_;
		goto BeforeRet_;
	}
LA5_: ;
	writeContext__msgs_u1111(conf_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	liMessage__msgs_u1227(conf_p0, info_p1, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)2), errMsg_p2, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), info2_p3, NIM_FALSE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___msgs_u714)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = toFileLineCol__msgs_u707(conf_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, getHash__msgs_u650)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1) {
	NimStringV2 result;
	result.len = 0; result.p = NIM_NIL;
	eqcopy___system_u2694((&result), (*conf_p0).m.fileInfos.p->data[fileIdx_p1].hash);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setHash__msgs_u643)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fileIdx_p1, NimStringV2 hash_p2) {
	eqcopy___system_u2694((&(*conf_p0).m.fileInfos.p->data[fileIdx_p1].hash), hash_p2);
}
N_LIB_PRIVATE N_NIMCALL(NIM_BOOL, exactEquals__msgs_u1107)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA a_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA b_p1) {
	NIM_BOOL result;
	NIM_BOOL T1_;
	NIM_BOOL T2_;
	T1_ = (NIM_BOOL)0;
	T2_ = (NIM_BOOL)0;
	T2_ = (a_p0.fileIndex == b_p1.fileIndex);
	if (!(T2_)) goto LA3_;
	T2_ = (a_p0.line == b_p1.line);
LA3_: ;
	T1_ = T2_;
	if (!(T1_)) goto LA4_;
	T1_ = (a_p0.col == b_p1.col);
LA4_: ;
	result = T1_;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, pushInfoContext__msgs_u569)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, NimStringV2 detail_p2) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD_;
	NimStringV2 colontmpD__2;
	tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ T1_;
	colontmpD_ = eqdup___lineinfos_u2037(info_p1);
	T1_.Field0 = colontmpD_;
	colontmpD__2 = eqdup___system_u2697(detail_p2);
	T1_.Field1 = colontmpD__2;
	add__msgs_u573((&(*conf_p0).m.msgContext), T1_);
}
N_LIB_PRIVATE N_NIMCALL(void, popInfoContext__msgs_u593)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NI T1_;
	T1_ = (*conf_p0).m.msgContext.len;
	setLen__lineinfos_u1862((&(*conf_p0).m.msgContext), ((NI)(T1_ - ((NI)1))));
}
N_LIB_PRIVATE N_NIMCALL(void, suggestWriteln__msgs_u459)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 s_p1) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	{
		if (!(((*conf_p0).m.errorOutputs &((NU8)1<<((NU)((((tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw)0)))&7U)))!=0)) goto LA3_;
		{
			tyArray__YgExxhfgKcesA5EOUj1MOA T9_;
			if (!((*conf_p0).writelnHook.ClP_0 == 0)) goto LA7_;
			T9_[0] = s_p1;
			writeLine__msgs_u470(stdout, T9_, 1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
			flushFile__stdZsyncio_u279(stdout);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
		goto LA5_;
LA7_: ;
		{
			(*conf_p0).writelnHook.ClE_0? (*conf_p0).writelnHook.ClP_0(s_p1, (*conf_p0).writelnHook.ClE_0):((TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_115)((*conf_p0).writelnHook.ClP_0))(s_p1);
			if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
		}
LA5_: ;
	}
LA3_: ;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, suggestQuit__msgs_u483)(void) {
	tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA* T1_;
{	T1_ = NIM_NIL;
	T1_ = (tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA*) nimNewObj(sizeof(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA), NIM_ALIGNOF(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__CLyaY3uTAyl9bLjvrz9aqX9bA_);
	(*T1_).Sup.Sup.Sup.name = "ESuggestDone";
	(*T1_).Sup.Sup.Sup.message = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_117;
	(*T1_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T1_, "ESuggestDone", "suggestQuit", "msgs.nim", 170);
goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NIM_BOOL, lteqpercent___system_u1072)(NI x_p0, NI y_p1) {
	NIM_BOOL result;
	result = ((NU64)(((NU) (x_p0))) <= (NU64)(((NU) (y_p1))));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, getInfoContext__msgs_u602)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI index_p1) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA result;
	NI colontmpD_;
	NI colontmpD__2;
	NI i_1;
	colontmpD_ = (NI)0;
	colontmpD__2 = (NI)0;
	{
		NI T5_;
		if (!(index_p1 < ((NI)0))) goto LA3_;
		T5_ = (*conf_p0).m.msgContext.len;
		colontmpD_ = (NI)(T5_ + index_p1);
		i_1 = colontmpD_;
	}
	goto LA1_;
LA3_: ;
	{
		colontmpD__2 = index_p1;
		i_1 = colontmpD__2;
	}
LA1_: ;
	{
		NI T9_;
		NIM_BOOL T10_;
		T9_ = (*conf_p0).m.msgContext.len;
		T10_ = (NIM_BOOL)0;
		T10_ = lteqpercent___system_u1072(T9_, i_1);
		if (!T10_) goto LA11_;
		result = unknownLineInfo__lineinfos_u364;
	}
	goto LA7_;
LA11_: ;
	{
		result = (*conf_p0).m.msgContext.p->data[i_1].Field0;
	}
LA7_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, formatMsg__msgs_u1220)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA info_p1, tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA msg_p2, NimStringV2 arg_p3) {
	NimStringV2 result;
	NimStringV2 title_1;
	NimStringV2 colontmpD_;
	NimStringV2 colontmpD__2;
	NimStringV2 T2_;
	NimStringV2 T6_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	title_1.len = 0; title_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	switch (msg_p2) {
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)20) ... ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)88):
	{
		title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_118;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)89) ... ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)123):
	{
		title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_119;
	}
	break;
	default:
	{
		title_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_120;
	}
	break;
	}
	T6_.len = 0; T6_.p = NIM_NIL;
	colontmpD_ = toFileLineCol__msgs_u707(conf_p0, info_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	colontmpD__2 = getMessageStr__msgs_u870(msg_p2, arg_p3);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T6_ = rawNewString(colontmpD_.len + title_1.len + colontmpD__2.len + 1);
appendString((&T6_), colontmpD_);
appendString((&T6_), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_121);
appendString((&T6_), title_1);
appendString((&T6_), colontmpD__2);
	result = T6_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI32, fileInfoIdx__msgs_u414)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NimStringV2 filename_p1) {
	NI32 result;
	NimStringV2 colontmpD_;
	NIM_BOOL dummy_1;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI32)0;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	dummy_1 = NIM_FALSE;
	colontmpD_ = nosexpandFilename(filename_p1);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	result = fileInfoIdx__msgs_u155(conf_p0, colontmpD_, (&dummy_1));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD_);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NI, getInfoContextLen__msgs_u556)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NI result;
	NI T1_;
{	T1_ = (*conf_p0).m.msgContext.len;
	result = T1_;
	goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, setInfoContextLen__msgs_u562)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI L_p1) {
	setLen__lineinfos_u1862((&(*conf_p0).m.msgContext), (L_p1));
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quotedFilename__msgs_u1630)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, NI32 fi_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	{
		if (!(fi_p1 < ((NI32)0))) goto LA3_;
		result = makeCString__msgs_u83(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_122);
		if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}
	goto LA1_;
LA3_: ;
	{
		if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)36)))&63U)))!=0)) goto LA6_;
		eqcopy___system_u2694((&result), (*conf_p0).m.fileInfos.p->data[fi_p1].quotedFullName);
	}
	goto LA1_;
LA6_: ;
	{
		eqcopy___system_u2694((&result), (*conf_p0).m.fileInfos.p->data[fi_p1].quotedName);
	}
LA1_: ;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, quotedFilename__msgs_u1638)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0, tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p1) {
	NimStringV2 result;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result.len = 0; result.p = NIM_NIL;
	result = quotedFilename__msgs_u1630(conf_p0, i_p1.fileIndex);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
static N_INLINE(NIM_BOOL, isEmpty__options_u3633)(NimStringV2 x_p0) {
	NIM_BOOL result;
	result = (x_p0.len == ((NI)0));
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, genSuccessX__msgs_u1683)(tyObject_ConfigRefcolonObjectType___S9atckdgEHYT7qfQK9cvzJOg* conf_p0) {
	NimStringV2 mem_1;
	NimStringV2 colontmpD_;
	NimStringV2 loc_1;
	NimStringV2 build_1;
	NimStringV2 flags_1;
	NimStringV2 sec_1;
	NimStringV2 project_1;
	NimStringV2 output_1;
	NimStringV2 argX60gensym145__1;
	NimStringV2 colontmpD__2;
	NimStringV2 T2_;
	NI T3_;
	NF T52_;
	NimStringV2 T53_;
	tyArray__ZZ0jy0VwqpvoX7GeaU0HUw T82_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	mem_1.len = 0; mem_1.p = NIM_NIL;
	colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
	loc_1.len = 0; loc_1.p = NIM_NIL;
	build_1.len = 0; build_1.p = NIM_NIL;
	flags_1.len = 0; flags_1.p = NIM_NIL;
	sec_1.len = 0; sec_1.p = NIM_NIL;
	project_1.len = 0; project_1.p = NIM_NIL;
	output_1.len = 0; output_1.p = NIM_NIL;
	argX60gensym145__1.len = 0; argX60gensym145__1.p = NIM_NIL;
	colontmpD__2.len = 0; colontmpD__2.p = NIM_NIL;
	T2_.len = 0; T2_.p = NIM_NIL;
	T3_ = (NI)0;
	T3_ = getMaxMem__system_u7220();
	colontmpD_ = formatSize__pureZstrutils_u2341(((NI64) (T3_)), 46, ((tyEnum_BinaryPrefixMode__DD8vm6t9bnCX9aiA69bRJXJtQ)0), NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T2_ = rawNewString(colontmpD_.len + 8);
appendString((&T2_), colontmpD_);
appendString((&T2_), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_124);
	mem_1 = T2_;
	loc_1 = dollar___systemZdollars_u9((*conf_p0).linesCompiled);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	build_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_125;
	flags_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_126;
	{
		if (!((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)3) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)4) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)5) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6))) goto LA6_;
		{
			NimStringV2 colontmpD__3;
			NimStringV2 colontmpD__4;
			if (!!(((*conf_p0).backend == ((tyEnum_TBackend__CGWF9bdzxEysXyGIUwpK8cw)3)))) goto LA10_;
			colontmpD__3.len = 0; colontmpD__3.p = NIM_NIL;
			colontmpD__4.len = 0; colontmpD__4.p = NIM_NIL;
			colontmpD__3 = dollar___options_u213((*conf_p0).selectedGC);
			colontmpD__4 = nsuFormatSingleElem(TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_128, colontmpD__3);
			if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
			prepareAdd((&build_1), colontmpD__4.len + 0);
appendString((&build_1), colontmpD__4);
			{
				if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)25)))&63U)))!=0)) goto LA15_;
				prepareAdd((&build_1), 13);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_130);
			}
LA15_: ;
			prepareAdd((&build_1), 5);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_132);
			{
				if (!(((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)15)))&31U)))!=0)) goto LA19_;
				prepareAdd((&build_1), 5);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_134);
			}
			goto LA17_;
LA19_: ;
			{
				if (!(((*conf_p0).options &((NU32)1<<((NU)((((tyEnum_TOption__LEwWf0yAgZkZx5Got2wGSQ)16)))&31U)))!=0)) goto LA22_;
				prepareAdd((&build_1), 4);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_136);
			}
			goto LA17_;
LA22_: ;
			{
				prepareAdd((&build_1), 54);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_138);
			}
LA17_: ;
			{
				NIM_BOOL T27_;
				T27_ = (NIM_BOOL)0;
				T27_ = isDefined__options_u959(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_140);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				if (!T27_) goto LA28_;
				prepareAdd((&flags_1), 10);
appendString((&flags_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_142);
			}
			goto LA25_;
LA28_: ;
			{
				NIM_BOOL T31_;
				T31_ = (NIM_BOOL)0;
				T31_ = isDefined__options_u959(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_144);
				if (NIM_UNLIKELY(*nimErr_)) goto LA12_;
				if (!T31_) goto LA32_;
				prepareAdd((&flags_1), 11);
appendString((&flags_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_146);
			}
			goto LA25_;
LA32_: ;
LA25_: ;
			{
				LA12_:;
			}
			{
				eqdestroy___system_u2691(colontmpD__4);
				eqdestroy___system_u2691(colontmpD__3);
			}
			if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		}
		goto LA8_;
LA10_: ;
		{
			prepareAdd((&build_1), 5);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_147);
			{
				NIM_BOOL T39_;
				T39_ = (NIM_BOOL)0;
				T39_ = isDefined__options_u959(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_148);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T39_) goto LA40_;
				prepareAdd((&build_1), 5);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_149);
				prepareAdd((&flags_1), 10);
appendString((&flags_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_150);
			}
			goto LA37_;
LA40_: ;
			{
				NIM_BOOL T43_;
				T43_ = (NIM_BOOL)0;
				T43_ = isDefined__options_u959(conf_p0, TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_151);
				if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
				if (!T43_) goto LA44_;
				prepareAdd((&build_1), 5);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_152);
				prepareAdd((&flags_1), 11);
appendString((&flags_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_153);
			}
			goto LA37_;
LA44_: ;
			{
				prepareAdd((&build_1), 54);
appendString((&build_1), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_154);
			}
LA37_: ;
		}
LA8_: ;
		{
			NimStringV2 colontmpD__5;
			NimStringV2 T51_;
			if (!(((NI)0) < flags_1.len)) goto LA49_;
			colontmpD__5.len = 0; colontmpD__5.p = NIM_NIL;
			T51_.len = 0; T51_.p = NIM_NIL;
			T51_ = rawNewString(flags_1.len + 10);
appendString((&T51_), TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_156);
appendString((&T51_), flags_1);
			colontmpD__5 = T51_;
			prepareAdd((&build_1), colontmpD__5.len + 0);
appendString((&build_1), colontmpD__5);
			eqdestroy___system_u2691(colontmpD__5);
		}
LA49_: ;
	}
LA6_: ;
	T52_ = (NF)0;
	T52_ = epochTime__pureZtimes_u5209();
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	sec_1 = nsuformatFloat(((NF)(T52_) - (NF)((*conf_p0).lastCmdTime)), ((tyEnum_FloatFormatMode__CTUpdhZ6zDNw9cC9acViKeYg)1), ((NI)3), 46);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T53_.len = 0; T53_.p = NIM_NIL;
	{
		if (!((*conf_p0).filenameOption == ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0))) goto LA56_;
		project_1 = dollar___options_u3939((*conf_p0).projectFull);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA54_;
LA56_: ;
	{
		eqcopy___system_u2694((&project_1), (*conf_p0).projectName);
	}
LA54_: ;
	{
		NIM_BOOL T61_;
		T61_ = (NIM_BOOL)0;
		T61_ = (((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)4)))&63U)))!=0);
		if (!(T61_)) goto LA62_;
		T61_ = !(((*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)29)));
LA62_: ;
		if (!T61_) goto LA63_;
		output_1 = dollar___options_u3939((*conf_p0).jsonBuildFile);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
	goto LA59_;
LA63_: ;
	{
		NIM_BOOL T66_;
		T66_ = (NIM_BOOL)0;
		T66_ = isEmpty__options_u3633((*conf_p0).outFile);
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
		if (!(T66_)) goto LA67_;
		T66_ = !(((*conf_p0).cmd >= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)2) && (*conf_p0).cmd <= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)6) || (*conf_p0).cmd >= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)14) && (*conf_p0).cmd <= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)16) || (*conf_p0).cmd >= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)21) && (*conf_p0).cmd <= ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)24) || (*conf_p0).cmd == ((tyEnum_Command__juUdcDlEGhwCRcct3jVHmQ)29)));
LA67_: ;
		if (!T66_) goto LA68_;
		output_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_158;
	}
	goto LA59_;
LA68_: ;
	{
		if (!(((*conf_p0).globalOptions &((NU64)1<<((NU)((((tyEnum_TGlobalOption__bV0ebQD3RnR6keJ3pWsG8A)26)))&63U)))!=0)) goto LA71_;
		output_1 = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_160;
	}
	goto LA59_;
LA71_: ;
	{
		NimStringV2 colontmpD__6;
		colontmpD__6.len = 0; colontmpD__6.p = NIM_NIL;
		colontmpD__6 = absOutFile__options_u3622(conf_p0);
		if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
		output_1 = dollar___options_u3939(colontmpD__6);
		if (NIM_UNLIKELY(*nimErr_)) goto LA74_;
		{
			LA74_:;
		}
		{
			eqdestroy___system_u2691(colontmpD__6);
		}
		if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	}
LA59_: ;
	{
		NimStringV2 T81_;
		if (!!(((*conf_p0).filenameOption == ((tyEnum_FilenameOption__o3jmnnVs6HdBg5KcNAzYiQ)0)))) goto LA79_;
		T81_.len = 0; T81_.p = NIM_NIL;
		T81_ = nosextractFilename(output_1);
		if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___system_u2691(T81_); goto LA1_;}
		eqsink___system_u2700((&output_1), T81_);
	}
LA79_: ;
	colontmpD__2 = msgKindToString__msgs_u867(((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)90));
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	T82_[0] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_162;
	T82_[1] = build_1;
	T82_[2] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_164;
	T82_[3] = loc_1;
	T82_[4] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_166;
	T82_[5] = sec_1;
	T82_[6] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_168;
	T82_[7] = mem_1;
	T82_[8] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_170;
	T82_[9] = project_1;
	T82_[10] = TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_172;
	T82_[11] = output_1;
	argX60gensym145__1 = nsuFormatOpenArray(colontmpD__2, T82_, 12);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	liMessage__msgs_u1227(conf_p0, unknownLineInfo__lineinfos_u364, ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)90), argX60gensym145__1, ((tyEnum_TErrorHandling__9aJ2MrE0UrBy3xCw3BT762w)1), (&TM__9bxt9c9cHMsIpkKKq9ca25JhvQ_173), NIM_TRUE, NIM_FALSE);
	if (NIM_UNLIKELY(*nimErr_)) goto LA1_;
	{
		LA1_:;
	}
	{
		eqdestroy___system_u2691(colontmpD__2);
		eqdestroy___system_u2691(argX60gensym145__1);
		eqdestroy___system_u2691(output_1);
		eqdestroy___system_u2691(project_1);
		eqdestroy___system_u2691(sec_1);
		eqdestroy___system_u2691(flags_1);
		eqdestroy___system_u2691(build_1);
		eqdestroy___system_u2691(loc_1);
		eqdestroy___system_u2691(colontmpD_);
		eqdestroy___system_u2691(mem_1);
	}
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
